@@ -1,7 +1,9 @@
 /*
  * cmd_funcs.h
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -77,24 +79,19 @@ gboolean cmd_about(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_autoaway(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_autoconnect(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_autoping(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_away(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_beep(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_caps(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_chat(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_chlog(ProfWin *window, const char *const command, gchar **args);
+gboolean cmd_logging(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_clear(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_close(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_connect(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_decline(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_disco(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_sendfile(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_lastactivity(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_disconnect(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_dnd(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_flash(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_tray(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_gone(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_grlog(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_group(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_help(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_history(ProfWin *window, const char *const command, gchar **args);
@@ -103,14 +100,12 @@ gboolean cmd_receipts(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_info(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_intype(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_invite(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_invites(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_join(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_leave(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_log(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_msg(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_nick(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_notify(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_online(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_pgp(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_outtype(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_prefs(ProfWin *window, const char *const command, gchar **args);
@@ -124,7 +119,8 @@ gboolean cmd_roster(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_software(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_splash(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_states(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_status(ProfWin *window, const char *const command, gchar **args);
+gboolean cmd_status_get(ProfWin *window, const char *const command, gchar **args);
+gboolean cmd_status_set(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_sub(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_theme(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_tiny(ProfWin *window, const char *const command, gchar **args);
@@ -132,7 +128,6 @@ gboolean cmd_wintitle(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_vercheck(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_who(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_win(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_xa(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_alias(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_xmlconsole(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_ping(ProfWin *window, const char *const command, gchar **args);
@@ -150,10 +145,11 @@ gboolean cmd_time(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_resource(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_inpblock(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_titlebar(ProfWin *window, const char *const command, gchar **args);
+gboolean cmd_titlebar_show_hide(ProfWin *window, const char *const command, gchar **args);
+gboolean cmd_titlebar_use(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_mainwin(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_statusbar(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_inputwin(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_encwarn(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_script(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_export(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_charset(ProfWin *window, const char *const command, gchar **args);
@@ -189,7 +185,6 @@ gboolean cmd_tls_certpath(ProfWin *window, const char *const command, gchar **ar
 gboolean cmd_tls_trust(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_tls_trusted(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_tls_revoke(ProfWin *window, const char *const command, gchar **args);
-gboolean cmd_tls_show(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_tls_cert(ProfWin *window, const char *const command, gchar **args);
 
 gboolean cmd_otr_char(ProfWin *window, const char *const command, gchar **args);
@@ -225,4 +220,11 @@ gboolean cmd_omemo_untrust(ProfWin *window, const char *const command, gchar **a
 gboolean cmd_omemo_policy(ProfWin *window, const char *const command, gchar **args);
 gboolean cmd_omemo_clear_device_list(ProfWin *window, const char *const command, gchar **args);
 
+gboolean cmd_save(ProfWin *window, const char *const command, gchar **args);
+gboolean cmd_reload(ProfWin *window, const char *const command, gchar **args);
+
+gboolean cmd_paste(ProfWin *window, const char *const command, gchar **args);
+gboolean cmd_color(ProfWin *window, const char *const command, gchar **args);
+gboolean cmd_avatar(ProfWin *window, const char *const command, gchar **args);
+gboolean cmd_os(ProfWin *window, const char *const command, gchar **args);
 #endif
