@@ -1,8 +1,9 @@
 /*
  * common.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -443,7 +444,11 @@ int
 is_regular_file(const char *path)
 {
     struct stat st;
-    stat(path, &st);
+    int ret = stat(path, &st);
+    if (ret != 0) {
+        perror(NULL);
+        return 0;
+    }
     return S_ISREG(st.st_mode);
 }
 
@@ -451,7 +456,11 @@ int
 is_dir(const char *path)
 {
     struct stat st;
-    stat(path, &st);
+    int ret = stat(path, &st);
+    if (ret != 0) {
+        perror(NULL);
+        return 0;
+    }
     return S_ISDIR(st.st_mode);
 }
 
@@ -481,3 +490,23 @@ get_file_paths_recursive(const char *path, GSList **contents)
         entry = g_dir_read_name(directory);
     }
 }
+
+char*
+get_random_string(int length)
+{
+    GRand *prng;
+    char *rand;
+    char alphabet[] = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
+
+    rand = calloc(length+1, sizeof(char));
+
+    prng = g_rand_new();
+
+    int i;
+    for (i = 0; i < length; i++) {
+        rand[i] = alphabet[g_rand_int_range(prng, 0, sizeof(alphabet))];
+    }
+    g_rand_free(prng);
+
+    return rand;
+}
