@@ -1,7 +1,9 @@
 /*
  * files.h
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2018 - 2019 Michael Vetter <jubalh@idoru.org>
  *
  * This file is part of Profanity.
  *
@@ -43,6 +45,7 @@
 #define FILE_PLUGIN_SETTINGS "plugin_settings"
 #define FILE_PLUGIN_THEMES "plugin_themes"
 #define FILE_CAPSCACHE "capscache"
+#define FILE_PROFANITY_IDENTIFIER "profident"
 
 #define DIR_THEMES "themes"
 #define DIR_ICONS "icons"
