@@ -1,8 +1,9 @@
 /*
  * preferences.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -49,7 +50,8 @@
 #include "config/files.h"
 #include "config/conflists.h"
 
-// preference groups refer to the sections in .profrc, for example [ui]
+// preference groups refer to the sections in .profrc or theme files
+// for example [ui] but not [colours] which is handled in theme.c
 #define PREF_GROUP_LOGGING "logging"
 #define PREF_GROUP_CHATSTATES "chatstates"
 #define PREF_GROUP_UI "ui"
@@ -78,20 +80,9 @@ static const char* _get_key(preference_t pref);
 static gboolean _get_default_boolean(preference_t pref);
 static char* _get_default_string(preference_t pref);
 
-void
-prefs_load(void)
+void _prefs_load(void)
 {
-    GError *err;
-    prefs_loc = files_get_config_path(FILE_PROFRC);
-
-    if (g_file_test(prefs_loc, G_FILE_TEST_EXISTS)) {
-        g_chmod(prefs_loc, S_IRUSR | S_IWUSR);
-    }
-
-    prefs = g_key_file_new();
-    g_key_file_load_from_file(prefs, prefs_loc, G_KEY_FILE_KEEP_COMMENTS, NULL);
-
-    err = NULL;
+    GError *err = NULL;
     log_maxsize = g_key_file_get_integer(prefs, PREF_GROUP_LOGGING, "maxsize", &err);
     if (err) {
         log_maxsize = 0;
@@ -175,17 +166,59 @@ prefs_load(void)
     g_strfreev(triggers);
 }
 
+void
+prefs_reload(void)
+{
+    g_key_file_free(prefs);
+    prefs = NULL;
+
+    prefs = g_key_file_new();
+    g_key_file_load_from_file(prefs, prefs_loc, G_KEY_FILE_KEEP_COMMENTS, NULL);
+
+    _prefs_load();
+}
+
+void
+prefs_load(char *config_file)
+{
+
+    if (config_file == NULL) {
+        prefs_loc = files_get_config_path(FILE_PROFRC);
+    } else {
+        prefs_loc = config_file;
+    }
+
+    if (g_file_test(prefs_loc, G_FILE_TEST_EXISTS)) {
+        g_chmod(prefs_loc, S_IRUSR | S_IWUSR);
+    }
+
+    prefs = g_key_file_new();
+    g_key_file_load_from_file(prefs, prefs_loc, G_KEY_FILE_KEEP_COMMENTS, NULL);
+
+    _prefs_load();
+}
+
+void
+prefs_save(void)
+{
+    _save_prefs();
+}
+
 void
 prefs_close(void)
 {
     autocomplete_free(boolean_choice_ac);
     autocomplete_free(room_trigger_ac);
+
     g_key_file_free(prefs);
     prefs = NULL;
+
+    free(prefs_loc);
+    prefs_loc = NULL;
 }
 
 char*
-prefs_autocomplete_boolean_choice(const char *const prefix, gboolean previous)
+prefs_autocomplete_boolean_choice(const char *const prefix, gboolean previous, void *context)
 {
     return autocomplete_complete(boolean_choice_ac, prefix, TRUE, previous);
 }
@@ -197,7 +230,7 @@ prefs_reset_boolean_choice(void)
 }
 
 char*
-prefs_autocomplete_room_trigger(const char *const prefix, gboolean previous)
+prefs_autocomplete_room_trigger(const char *const prefix, gboolean previous, void *context)
 {
     return autocomplete_complete(room_trigger_ac, prefix, TRUE, previous);
 }
@@ -334,21 +367,18 @@ void
 prefs_set_room_notify(const char *const roomjid, gboolean value)
 {
     g_key_file_set_boolean(prefs, roomjid, "notify", value);
-    _save_prefs();
 }
 
 void
 prefs_set_room_notify_mention(const char *const roomjid, gboolean value)
 {
     g_key_file_set_boolean(prefs, roomjid, "notify.mention", value);
-    _save_prefs();
 }
 
 void
 prefs_set_room_notify_trigger(const char *const roomjid, gboolean value)
 {
     g_key_file_set_boolean(prefs, roomjid, "notify.trigger", value);
-    _save_prefs();
 }
 
 gboolean
@@ -392,7 +422,6 @@ prefs_reset_room_notify(const char *const roomjid)
 {
     if (g_key_file_has_group(prefs, roomjid)) {
         g_key_file_remove_group(prefs, roomjid, NULL);
-        _save_prefs();
         return TRUE;
     }
 
@@ -419,7 +448,6 @@ prefs_set_boolean(preference_t pref, gboolean value)
     const char *group = _get_group(pref);
     const char *key = _get_key(pref);
     g_key_file_set_boolean(prefs, group, key, value);
-    _save_prefs();
 }
 
 char*
@@ -460,7 +488,6 @@ prefs_set_string(preference_t pref, char *value)
     } else {
         g_key_file_set_string(prefs, group, key, value);
     }
-    _save_prefs();
 }
 
 char*
@@ -512,7 +539,6 @@ void
 prefs_set_gone(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_CHATSTATES, "gone", value);
-    _save_prefs();
 }
 
 gint
@@ -525,7 +551,6 @@ void
 prefs_set_notify_remind(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_NOTIFICATIONS, "remind", value);
-    _save_prefs();
 }
 
 gint
@@ -542,7 +567,6 @@ prefs_set_max_log_size(gint value)
 {
     log_maxsize = value;
     g_key_file_set_integer(prefs, PREF_GROUP_LOGGING, "maxsize", value);
-    _save_prefs();
 }
 
 gint
@@ -560,7 +584,6 @@ void
 prefs_set_inpblock(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_UI, "inpblock", value);
-    _save_prefs();
 }
 
 gint
@@ -577,7 +600,6 @@ void
 prefs_set_reconnect(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_CONNECTION, "reconnect", value);
-    _save_prefs();
 }
 
 gint
@@ -594,7 +616,6 @@ void
 prefs_set_autoping(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_CONNECTION, "autoping", value);
-    _save_prefs();
 }
 
 gint
@@ -611,7 +632,6 @@ void
 prefs_set_autoping_timeout(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_CONNECTION, "autoping.timeout", value);
-    _save_prefs();
 }
 
 gint
@@ -636,21 +656,18 @@ void
 prefs_set_autoaway_time(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_PRESENCE, "autoaway.awaytime", value);
-    _save_prefs();
 }
 
 void
 prefs_set_autoxa_time(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_PRESENCE, "autoaway.xatime", value);
-    _save_prefs();
 }
 
 void
 prefs_set_tray_timer(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_NOTIFICATIONS, "tray.timer", value);
-    _save_prefs();
 }
 
 gint
@@ -679,7 +696,6 @@ void
 prefs_set_statusbartabs(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_UI, "statusbar.tabs", value);
-    _save_prefs();
 }
 
 gint
@@ -696,7 +712,6 @@ void
 prefs_set_statusbartablen(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_UI, "statusbar.tablen", value);
-    _save_prefs();
 }
 
 gchar**
@@ -736,7 +751,6 @@ void
 prefs_set_occupants_size(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_UI, "occupants.size", value);
-    _save_prefs();
 }
 
 gint
@@ -775,14 +789,12 @@ prefs_set_occupants_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_UI, "occupants.char", str);
-    _save_prefs();
 }
 
 void
 prefs_clear_occupants_char(void)
 {
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "occupants.char", NULL);
-    _save_prefs();
 }
 
 gint
@@ -804,7 +816,6 @@ void
 prefs_set_occupants_indent(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_UI, "occupants.indent", value);
-    _save_prefs();
 }
 
 char
@@ -831,21 +842,18 @@ prefs_set_occupants_header_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_UI, "occupants.header.char", str);
-    _save_prefs();
 }
 
 void
 prefs_clear_occupants_header_char(void)
 {
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "occupants.header.char", NULL);
-    _save_prefs();
 }
 
 void
 prefs_set_roster_size(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_UI, "roster.size", value);
-    _save_prefs();
 }
 
 gint
@@ -884,7 +892,6 @@ prefs_set_otr_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_OTR, "otr.char", str);
-    _save_prefs();
 }
 
 char
@@ -911,7 +918,6 @@ prefs_set_pgp_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_PGP, "pgp.char", str);
-    _save_prefs();
 }
 
 char
@@ -938,7 +944,6 @@ prefs_set_omemo_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_OMEMO, "omemo.char", str);
-    _save_prefs();
 }
 
 char
@@ -965,14 +970,12 @@ prefs_set_roster_header_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.header.char", str);
-    _save_prefs();
 }
 
 void
 prefs_clear_roster_header_char(void)
 {
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.header.char", NULL);
-    _save_prefs();
 }
 
 char
@@ -999,14 +1002,12 @@ prefs_set_roster_contact_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.contact.char", str);
-    _save_prefs();
 }
 
 void
 prefs_clear_roster_contact_char(void)
 {
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.contact.char", NULL);
-    _save_prefs();
 }
 
 char
@@ -1033,14 +1034,12 @@ prefs_set_roster_resource_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.resource.char", str);
-    _save_prefs();
 }
 
 void
 prefs_clear_roster_resource_char(void)
 {
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.resource.char", NULL);
-    _save_prefs();
 }
 
 char
@@ -1067,14 +1066,12 @@ prefs_set_roster_private_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.private.char", str);
-    _save_prefs();
 }
 
 void
 prefs_clear_roster_private_char(void)
 {
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.private.char", NULL);
-    _save_prefs();
 }
 
 char
@@ -1101,14 +1098,12 @@ prefs_set_roster_room_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.rooms.char", str);
-    _save_prefs();
 }
 
 void
 prefs_clear_roster_room_char(void)
 {
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.rooms.char", NULL);
-    _save_prefs();
 }
 
 char
@@ -1135,14 +1130,12 @@ prefs_set_roster_room_private_char(char ch)
     str[1] = '\0';
 
     g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.rooms.private.char", str);
-    _save_prefs();
 }
 
 void
 prefs_clear_roster_room_private_char(void)
 {
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.rooms.pruvate.char", NULL);
-    _save_prefs();
 }
 
 gint
@@ -1164,7 +1157,6 @@ void
 prefs_set_roster_contact_indent(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_UI, "roster.contact.indent", value);
-    _save_prefs();
 }
 
 gint
@@ -1186,7 +1178,6 @@ void
 prefs_set_roster_resource_indent(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_UI, "roster.resource.indent", value);
-    _save_prefs();
 }
 
 gint
@@ -1208,14 +1199,12 @@ void
 prefs_set_roster_presence_indent(gint value)
 {
     g_key_file_set_integer(prefs, PREF_GROUP_UI, "roster.presence.indent", value);
-    _save_prefs();
 }
 
 gboolean
 prefs_add_room_notify_trigger(const char * const text)
 {
     gboolean res = conf_string_list_add(prefs, PREF_GROUP_NOTIFICATIONS, "room.trigger.list", text);
-    _save_prefs();
 
     if (res) {
         autocomplete_add(room_trigger_ac, text);
@@ -1527,7 +1516,6 @@ prefs_statusbar_pos_down(void)
     return FALSE;
 }
 
-
 gboolean
 prefs_inputwin_pos_down(void)
 {
@@ -1563,7 +1551,6 @@ prefs_add_alias(const char *const name, const char *const value)
         return FALSE;
     } else {
         g_key_file_set_string(prefs, PREF_GROUP_ALIAS, name, value);
-        _save_prefs();
         return TRUE;
     }
 }
@@ -1582,7 +1569,6 @@ prefs_remove_alias(const char *const name)
         return FALSE;
     } else {
         g_key_file_remove_key(prefs, PREF_GROUP_ALIAS, name, NULL);
-        _save_prefs();
         return TRUE;
     }
 }
@@ -1665,6 +1651,7 @@ _get_group(preference_t pref)
 {
     switch (pref)
     {
+        case PREF_CLEAR_PERSIST_HISTORY:
         case PREF_SPLASH:
         case PREF_BEEP:
         case PREF_THEME:
@@ -1714,6 +1701,7 @@ _get_group(preference_t pref)
         case PREF_ROSTER_ROOMS_ORDER:
         case PREF_ROSTER_ROOMS_UNREAD:
         case PREF_ROSTER_ROOMS_SERVER:
+        case PREF_ROSTER_ROOMS_USE_AS_NAME:
         case PREF_ROSTER_PRIVATE:
         case PREF_RESOURCE_TITLE:
         case PREF_RESOURCE_MESSAGE:
@@ -1723,11 +1711,15 @@ _get_group(preference_t pref)
         case PREF_CONSOLE_MUC:
         case PREF_CONSOLE_PRIVATE:
         case PREF_CONSOLE_CHAT:
+        case PREF_COLOR_NICK:
+        case PREF_ROSTER_COLOR_NICK:
+        case PREF_OCCUPANTS_COLOR_NICK:
         case PREF_STATUSBAR_SHOW_NAME:
         case PREF_STATUSBAR_SHOW_NUMBER:
         case PREF_STATUSBAR_SELF:
         case PREF_STATUSBAR_CHAT:
         case PREF_STATUSBAR_ROOM:
+        case PREF_TITLEBAR_MUC_TITLE:
             return PREF_GROUP_UI;
         case PREF_STATES:
         case PREF_OUTTYPE:
@@ -1748,6 +1740,7 @@ _get_group(preference_t pref)
         case PREF_NOTIFY_MENTION_WHOLE_WORD:
         case PREF_TRAY:
         case PREF_TRAY_READ:
+        case PREF_ADV_NOTIFY_DISCO_OR_VERSION:
             return PREF_GROUP_NOTIFICATIONS;
         case PREF_CHLOG:
         case PREF_GRLOG:
@@ -1765,6 +1758,7 @@ _get_group(preference_t pref)
         case PREF_CARBONS:
         case PREF_RECEIPTS_SEND:
         case PREF_RECEIPTS_REQUEST:
+        case PREF_REVEAL_OS:
         case PREF_TLS_CERTPATH:
             return PREF_GROUP_CONNECTION;
         case PREF_OTR_LOG:
@@ -1792,6 +1786,8 @@ _get_key(preference_t pref)
 {
     switch (pref)
     {
+        case PREF_CLEAR_PERSIST_HISTORY:
+            return "clear.persist_history";
         case PREF_SPLASH:
             return "splash";
         case PREF_BEEP:
@@ -1810,6 +1806,8 @@ _get_key(preference_t pref)
             return "tray";
         case PREF_TRAY_READ:
             return "tray.read";
+        case PREF_ADV_NOTIFY_DISCO_OR_VERSION:
+            return "adv.notify.discoversion";
         case PREF_INTYPE:
             return "intype";
         case PREF_HISTORY:
@@ -1820,6 +1818,8 @@ _get_key(preference_t pref)
             return "receipts.send";
         case PREF_RECEIPTS_REQUEST:
             return "receipts.request";
+        case PREF_REVEAL_OS:
+            return "reveal.os";
         case PREF_OCCUPANTS:
             return "occupants";
         case PREF_OCCUPANTS_JID:
@@ -1956,6 +1956,8 @@ _get_key(preference_t pref)
             return "roster.rooms.unread";
         case PREF_ROSTER_ROOMS_SERVER:
             return "roster.rooms.server";
+        case PREF_ROSTER_ROOMS_USE_AS_NAME:
+            return "roster.rooms.use.name";
         case PREF_ROSTER_PRIVATE:
             return "roster.private";
         case PREF_RESOURCE_TITLE:
@@ -1966,6 +1968,8 @@ _get_key(preference_t pref)
             return "inpblock.dynamic";
         case PREF_ENC_WARN:
             return "enc.warn";
+        case PREF_TITLEBAR_MUC_TITLE:
+            return "titlebar.muc.title";
         case PREF_PGP_LOG:
             return "log";
         case PREF_TLS_CERTPATH:
@@ -1980,6 +1984,12 @@ _get_key(preference_t pref)
             return "console.private";
         case PREF_CONSOLE_CHAT:
             return "console.chat";
+        case PREF_COLOR_NICK:
+            return "color.nick";
+        case PREF_ROSTER_COLOR_NICK:
+            return "color.roster.nick";
+        case PREF_OCCUPANTS_COLOR_NICK:
+            return "color.occupants.nick";
         case PREF_BOOKMARK_INVITE:
             return "bookmark.invite";
         case PREF_PLUGINS_SOURCEPATH:
@@ -2049,6 +2059,7 @@ _get_default_boolean(preference_t pref)
         case PREF_BOOKMARK_INVITE:
         case PREF_ROOM_LIST_CACHE:
         case PREF_STATUSBAR_SHOW_NUMBER:
+        case PREF_REVEAL_OS:
             return TRUE;
         default:
             return FALSE;
@@ -2084,6 +2095,10 @@ _get_default_string(preference_t pref)
             return "last";
         case PREF_ROSTER_ROOMS_BY:
             return "none";
+        case PREF_ROSTER_ROOMS_USE_AS_NAME:
+            return "name";
+        case PREF_TITLEBAR_MUC_TITLE:
+            return "name";
         case PREF_ROSTER_ROOMS_ORDER:
             return "name";
         case PREF_ROSTER_ROOMS_UNREAD:
@@ -2122,6 +2137,8 @@ _get_default_string(preference_t pref)
             return "redact";
         case PREF_OMEMO_POLICY:
             return "automatic";
+        case PREF_COLOR_NICK:
+            return "false";
         default:
             return NULL;
     }
