@@ -1,7 +1,9 @@
 /*
  * preferences.h
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -45,6 +47,7 @@
 // represents all settings in .profrc
 // each enum value is mapped to a group and key in .profrc (see preferences.c)
 typedef enum {
+    PREF_CLEAR_PERSIST_HISTORY,
     PREF_SPLASH,
     PREF_BEEP,
     PREF_VERCHECK,
@@ -54,11 +57,13 @@ typedef enum {
     PREF_FLASH,
     PREF_TRAY,
     PREF_TRAY_READ,
+    PREF_ADV_NOTIFY_DISCO_OR_VERSION,
     PREF_INTYPE,
     PREF_HISTORY,
     PREF_CARBONS,
     PREF_RECEIPTS_SEND,
     PREF_RECEIPTS_REQUEST,
+    PREF_REVEAL_OS,
     PREF_OCCUPANTS,
     PREF_OCCUPANTS_SIZE,
     PREF_OCCUPANTS_JID,
@@ -85,6 +90,7 @@ typedef enum {
     PREF_ROSTER_ROOMS_ORDER,
     PREF_ROSTER_ROOMS_UNREAD,
     PREF_ROSTER_ROOMS_SERVER,
+    PREF_ROSTER_ROOMS_USE_AS_NAME,
     PREF_ROSTER_PRIVATE,
     PREF_MUC_PRIVILEGES,
     PREF_PRESENCE,
@@ -133,6 +139,7 @@ typedef enum {
     PREF_RESOURCE_MESSAGE,
     PREF_INPBLOCK_DYNAMIC,
     PREF_ENC_WARN,
+    PREF_TITLEBAR_MUC_TITLE,
     PREF_PGP_LOG,
     PREF_TLS_CERTPATH,
     PREF_TLS_SHOW,
@@ -140,6 +147,9 @@ typedef enum {
     PREF_CONSOLE_MUC,
     PREF_CONSOLE_PRIVATE,
     PREF_CONSOLE_CHAT,
+    PREF_COLOR_NICK,
+    PREF_ROSTER_COLOR_NICK,
+    PREF_OCCUPANTS_COLOR_NICK,
     PREF_BOOKMARK_INVITE,
     PREF_PLUGINS_SOURCEPATH,
     PREF_ROOM_LIST_CACHE,
@@ -165,16 +175,18 @@ typedef struct prof_winplacement_t {
     int inputwin_pos;
 } ProfWinPlacement;
 
-void prefs_load(void);
+void prefs_load(char *config_file);
+void prefs_save(void);
 void prefs_close(void);
+void prefs_reload(void);
 
 char* prefs_find_login(char *prefix);
 void prefs_reset_login_search(void);
 
-char* prefs_autocomplete_boolean_choice(const char *const prefix, gboolean previous);
+char* prefs_autocomplete_boolean_choice(const char *const prefix, gboolean previous, void *context);
 void prefs_reset_boolean_choice(void);
 
-char* prefs_autocomplete_room_trigger(const char *const prefix, gboolean previous);
+char* prefs_autocomplete_room_trigger(const char *const prefix, gboolean previous, void *context);
 void prefs_reset_room_trigger_ac(void);
 
 gint prefs_get_gone(void);
