@@ -1,8 +1,9 @@
 /*
  * theme.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -51,20 +52,15 @@
 #include "config/files.h"
 #include "config/theme.h"
 #include "config/preferences.h"
+#include "config/color.h"
 
 static GString *theme_loc;
 static GKeyFile *theme;
 static GHashTable *bold_items;
-static GHashTable *str_to_pair;
 static GHashTable *defaults;
 
-struct colour_string_t {
-    char *str;
-    NCURSES_COLOR_T colour;
-};
-
 static void _load_preferences(void);
-void _theme_list_dir(const gchar *const dir, GSList **result);
+static void _theme_list_dir(const gchar *const dir, GSList **result);
 static GString* _theme_find(const char *const theme_name);
 static gboolean _theme_load_file(const char *const theme_name);
 
@@ -75,20 +71,21 @@ theme_init(const char *const theme_name)
         log_error("Theme initialisation failed");
     }
 
-    str_to_pair = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
     defaults = g_hash_table_new_full(g_str_hash, g_str_equal, free, free);
 
-    g_hash_table_insert(defaults, strdup("main.text"),               strdup("white"));
-    g_hash_table_insert(defaults, strdup("main.text.me"),            strdup("white"));
-    g_hash_table_insert(defaults, strdup("main.text.them"),          strdup("white"));
+    // Set default colors
+    g_hash_table_insert(defaults, strdup("main.text"),               strdup("default"));
+    g_hash_table_insert(defaults, strdup("main.text.history"),       strdup("default"));
+    g_hash_table_insert(defaults, strdup("main.text.me"),            strdup("default"));
+    g_hash_table_insert(defaults, strdup("main.text.them"),          strdup("default"));
     g_hash_table_insert(defaults, strdup("main.splash"),             strdup("cyan"));
-    g_hash_table_insert(defaults, strdup("main.help.header"),        strdup("white"));
+    g_hash_table_insert(defaults, strdup("main.help.header"),        strdup("default"));
     g_hash_table_insert(defaults, strdup("error"),                   strdup("red"));
     g_hash_table_insert(defaults, strdup("incoming"),                strdup("yellow"));
     g_hash_table_insert(defaults, strdup("mention"),                 strdup("yellow"));
     g_hash_table_insert(defaults, strdup("trigger"),                 strdup("yellow"));
-    g_hash_table_insert(defaults, strdup("input.text"),              strdup("white"));
-    g_hash_table_insert(defaults, strdup("main.time"),               strdup("white"));
+    g_hash_table_insert(defaults, strdup("input.text"),              strdup("default"));
+    g_hash_table_insert(defaults, strdup("main.time"),               strdup("default"));
     g_hash_table_insert(defaults, strdup("titlebar.text"),           strdup("white"));
     g_hash_table_insert(defaults, strdup("titlebar.brackets"),       strdup("cyan"));
     g_hash_table_insert(defaults, strdup("titlebar.unencrypted"),    strdup("red"));
@@ -104,6 +101,7 @@ theme_init(const char *const theme_name)
     g_hash_table_insert(defaults, strdup("statusbar.text"),          strdup("white"));
     g_hash_table_insert(defaults, strdup("statusbar.brackets"),      strdup("cyan"));
     g_hash_table_insert(defaults, strdup("statusbar.active"),        strdup("cyan"));
+    g_hash_table_insert(defaults, strdup("statusbar.current"),       strdup("cyan"));
     g_hash_table_insert(defaults, strdup("statusbar.new"),           strdup("white"));
     g_hash_table_insert(defaults, strdup("statusbar.time"),          strdup("white"));
     g_hash_table_insert(defaults, strdup("me"),                      strdup("yellow"));
@@ -154,8 +152,9 @@ theme_init(const char *const theme_name)
     g_hash_table_insert(defaults, strdup("roster.room.mention"),     strdup("green"));
     g_hash_table_insert(defaults, strdup("occupants.header"),        strdup("yellow"));
     g_hash_table_insert(defaults, strdup("untrusted"),               strdup("red"));
+    g_hash_table_insert(defaults, strdup("cmd.wins.unread"),         strdup("default"));
 
-    _load_preferences();
+    //_load_preferences();
 }
 
 gboolean
@@ -175,10 +174,14 @@ theme_exists(const char *const theme_name)
 }
 
 gboolean
-theme_load(const char *const theme_name)
+theme_load(const char *const theme_name, gboolean load_theme_prefs)
 {
+    color_pair_cache_reset();
+
     if (_theme_load_file(theme_name)) {
-        _load_preferences();
+        if (load_theme_prefs) {
+            _load_preferences();
+        }
         return TRUE;
     } else {
         return FALSE;
@@ -224,11 +227,13 @@ theme_list(void)
 {
     GSList *result = NULL;
     char *themes_dir = files_get_config_path(DIR_THEMES);
+
     _theme_list_dir(themes_dir, &result);
     free(themes_dir);
 #ifdef THEMES_PATH
     _theme_list_dir(THEMES_PATH, &result);
 #endif
+
     return result;
 }
 
@@ -247,117 +252,17 @@ theme_close(void)
         g_hash_table_destroy(bold_items);
         bold_items = NULL;
     }
-    if (str_to_pair) {
-        g_hash_table_destroy(str_to_pair);
-        str_to_pair = NULL;
-    }
     if (defaults) {
         g_hash_table_destroy(defaults);
         defaults = NULL;
     }
 }
 
-static void
-_theme_init_pair(short pair, short fgnd, short bgnd, char *pair_str)
-{
-    init_pair(pair, fgnd, bgnd);
-    g_hash_table_insert(str_to_pair, strdup(pair_str), GINT_TO_POINTER((int)pair));
-}
-
 void
 theme_init_colours(void)
 {
     assume_default_colors(-1, -1);
-    g_hash_table_insert(str_to_pair, strdup("default_default"), 0);
-
-    _theme_init_pair(1, -1, COLOR_BLACK,                "default_black");
-    _theme_init_pair(2, -1, COLOR_BLUE,                 "default_blue");
-    _theme_init_pair(3, -1, COLOR_GREEN,                "default_green");
-    _theme_init_pair(4, -1, COLOR_RED,                  "default_red");
-    _theme_init_pair(5, -1, COLOR_CYAN,                 "default_cyan");
-    _theme_init_pair(6, -1, COLOR_MAGENTA,              "default_magenta");
-    _theme_init_pair(7, -1, COLOR_WHITE,                "default_white");
-    _theme_init_pair(8, -1, COLOR_YELLOW,               "default_yellow");
-
-    _theme_init_pair(9,  COLOR_BLACK, -1,               "black_default");
-    _theme_init_pair(10, COLOR_BLACK, COLOR_BLACK,      "black_black");
-    _theme_init_pair(11, COLOR_BLACK, COLOR_BLUE,       "black_blue");
-    _theme_init_pair(12, COLOR_BLACK, COLOR_GREEN,      "black_green");
-    _theme_init_pair(13, COLOR_BLACK, COLOR_RED,        "black_red");
-    _theme_init_pair(14, COLOR_BLACK, COLOR_CYAN,       "black_cyan");
-    _theme_init_pair(15, COLOR_BLACK, COLOR_MAGENTA,    "black_magenta");
-    _theme_init_pair(16, COLOR_BLACK, COLOR_WHITE,      "black_white");
-    _theme_init_pair(17, COLOR_BLACK, COLOR_YELLOW,     "black_yellow");
-
-    _theme_init_pair(18, COLOR_BLUE, -1,                "blue_default");
-    _theme_init_pair(19, COLOR_BLUE, COLOR_BLACK,       "blue_black");
-    _theme_init_pair(20, COLOR_BLUE, COLOR_BLUE,        "blue_blue");
-    _theme_init_pair(21, COLOR_BLUE, COLOR_GREEN,       "blue_green");
-    _theme_init_pair(22, COLOR_BLUE, COLOR_RED,         "blue_red");
-    _theme_init_pair(23, COLOR_BLUE, COLOR_CYAN,        "blue_cyan");
-    _theme_init_pair(24, COLOR_BLUE, COLOR_MAGENTA,     "blue_magenta");
-    _theme_init_pair(25, COLOR_BLUE, COLOR_WHITE,       "blue_white");
-    _theme_init_pair(26, COLOR_BLUE, COLOR_YELLOW,      "blue_yellow");
-
-    _theme_init_pair(27, COLOR_GREEN, -1,               "green_default");
-    _theme_init_pair(28, COLOR_GREEN, COLOR_BLACK,      "green_black");
-    _theme_init_pair(29, COLOR_GREEN, COLOR_BLUE,       "green_blue");
-    _theme_init_pair(30, COLOR_GREEN, COLOR_GREEN,      "green_green");
-    _theme_init_pair(31, COLOR_GREEN, COLOR_RED,        "green_red");
-    _theme_init_pair(32, COLOR_GREEN, COLOR_CYAN,       "green_cyan");
-    _theme_init_pair(33, COLOR_GREEN, COLOR_MAGENTA,    "green_magenta");
-    _theme_init_pair(34, COLOR_GREEN, COLOR_WHITE,      "green_white");
-    _theme_init_pair(35, COLOR_GREEN, COLOR_YELLOW,     "green_yellow");
-
-    _theme_init_pair(36, COLOR_RED, -1,                 "red_default");
-    _theme_init_pair(37, COLOR_RED, COLOR_BLACK,        "red_black");
-    _theme_init_pair(38, COLOR_RED, COLOR_BLUE,         "red_blue");
-    _theme_init_pair(39, COLOR_RED, COLOR_GREEN,        "red_green");
-    _theme_init_pair(40, COLOR_RED, COLOR_RED,          "red_red");
-    _theme_init_pair(41, COLOR_RED, COLOR_CYAN,         "red_cyan");
-    _theme_init_pair(42, COLOR_RED, COLOR_MAGENTA,      "red_magenta");
-    _theme_init_pair(43, COLOR_RED, COLOR_WHITE,        "red_white");
-    _theme_init_pair(44, COLOR_RED, COLOR_YELLOW,       "red_yellow");
-
-    _theme_init_pair(45, COLOR_CYAN, -1,                "cyan_default");
-    _theme_init_pair(46, COLOR_CYAN, COLOR_BLACK,       "cyan_black");
-    _theme_init_pair(47, COLOR_CYAN, COLOR_BLUE,        "cyan_blue");
-    _theme_init_pair(48, COLOR_CYAN, COLOR_GREEN,       "cyan_green");
-    _theme_init_pair(49, COLOR_CYAN, COLOR_RED,         "cyan_red");
-    _theme_init_pair(50, COLOR_CYAN, COLOR_CYAN,        "cyan_cyan");
-    _theme_init_pair(51, COLOR_CYAN, COLOR_MAGENTA,     "cyan_magenta");
-    _theme_init_pair(52, COLOR_CYAN, COLOR_WHITE,       "cyan_white");
-    _theme_init_pair(53, COLOR_CYAN, COLOR_YELLOW,      "cyan_yellow");
-
-    _theme_init_pair(54, COLOR_MAGENTA, -1,             "magenta_default");
-    _theme_init_pair(55, COLOR_MAGENTA, COLOR_BLACK,    "magenta_black");
-    _theme_init_pair(56, COLOR_MAGENTA, COLOR_BLUE,     "magenta_blue");
-    _theme_init_pair(57, COLOR_MAGENTA, COLOR_GREEN,    "magenta_green");
-    _theme_init_pair(58, COLOR_MAGENTA, COLOR_RED,      "magenta_red");
-    _theme_init_pair(59, COLOR_MAGENTA, COLOR_CYAN,     "magenta_cyan");
-    _theme_init_pair(60, COLOR_MAGENTA, COLOR_MAGENTA,  "magenta_magenta");
-    _theme_init_pair(61, COLOR_MAGENTA, COLOR_WHITE,    "magenta_white");
-    _theme_init_pair(62, COLOR_MAGENTA, COLOR_YELLOW,   "magenta_yellow");
-
-    _theme_init_pair(63, COLOR_WHITE, -1,               "white_default");
-    _theme_init_pair(64, COLOR_WHITE, COLOR_BLACK,      "white_black");
-    _theme_init_pair(65, COLOR_WHITE, COLOR_BLUE,       "white_blue");
-    _theme_init_pair(66, COLOR_WHITE, COLOR_GREEN,      "white_green");
-    _theme_init_pair(67, COLOR_WHITE, COLOR_RED,        "white_red");
-    _theme_init_pair(68, COLOR_WHITE, COLOR_CYAN,       "white_cyan");
-    _theme_init_pair(69, COLOR_WHITE, COLOR_MAGENTA,    "white_magenta");
-    _theme_init_pair(70, COLOR_WHITE, COLOR_WHITE,      "white_white");
-    _theme_init_pair(71, COLOR_WHITE, COLOR_YELLOW,     "white_yellow");
-
-    _theme_init_pair(72, COLOR_YELLOW, -1,              "yellow_default");
-    _theme_init_pair(73, COLOR_YELLOW, COLOR_BLACK,     "yellow_black");
-    _theme_init_pair(74, COLOR_YELLOW, COLOR_BLUE,      "yellow_blue");
-    _theme_init_pair(75, COLOR_YELLOW, COLOR_GREEN,     "yellow_green");
-    _theme_init_pair(76, COLOR_YELLOW, COLOR_RED,       "yellow_red");
-    _theme_init_pair(77, COLOR_YELLOW, COLOR_CYAN,      "yellow_cyan");
-    _theme_init_pair(78, COLOR_YELLOW, COLOR_MAGENTA,   "yellow_magenta");
-    _theme_init_pair(79, COLOR_YELLOW, COLOR_WHITE,     "yellow_white");
-    _theme_init_pair(80, COLOR_YELLOW, COLOR_YELLOW,    "yellow_yellow");
+    color_pair_cache_reset();
 }
 
 static void
@@ -382,6 +287,7 @@ _set_boolean_preference(char *prefstr, preference_t pref)
 static void
 _load_preferences(void)
 {
+    // load booleans from theme and set them to prefs
     _set_boolean_preference("beep", PREF_BEEP);
     _set_boolean_preference("flash", PREF_FLASH);
     _set_boolean_preference("splash", PREF_SPLASH);
@@ -409,10 +315,12 @@ _load_preferences(void)
     _set_boolean_preference("presence", PREF_PRESENCE);
     _set_boolean_preference("intype", PREF_INTYPE);
     _set_boolean_preference("enc.warn", PREF_ENC_WARN);
+    _set_boolean_preference("titlebar.muc.title", PREF_TITLEBAR_MUC_TITLE);
     _set_boolean_preference("tls.show", PREF_TLS_SHOW);
     _set_boolean_preference("statusbar.show.name", PREF_STATUSBAR_SHOW_NAME);
     _set_boolean_preference("statusbar.show.number", PREF_STATUSBAR_SHOW_NUMBER);
 
+    // load strings from theme and set them to prefs
     _set_string_preference("time.console", PREF_TIME_CONSOLE);
     _set_string_preference("time.chat", PREF_TIME_CHAT);
     _set_string_preference("time.muc", PREF_TIME_MUC);
@@ -436,10 +344,13 @@ _load_preferences(void)
     _set_string_preference("roster.rooms.by", PREF_ROSTER_ROOMS_BY);
     _set_string_preference("roster.private", PREF_ROSTER_PRIVATE);
     _set_string_preference("roster.count", PREF_ROSTER_COUNT);
+    _set_string_preference("roster.rooms.use.name", PREF_ROSTER_ROOMS_USE_AS_NAME);
     _set_string_preference("statusbar.self", PREF_STATUSBAR_SELF);
     _set_string_preference("statusbar.chat", PREF_STATUSBAR_CHAT);
     _set_string_preference("statusbar.room", PREF_STATUSBAR_ROOM);
 
+    // load ints from theme and set them to prefs
+    // with custom set functions
     if (g_key_file_has_key(theme, "ui", "statusbar.tabs", NULL)) {
         gint tabs_size = g_key_file_get_integer(theme, "ui", "statusbar.tabs", NULL);
         prefs_set_statusbartabs(tabs_size);
@@ -455,19 +366,39 @@ _load_preferences(void)
         prefs_set_occupants_size(occupants_size);
     }
 
+    if (g_key_file_has_key(theme, "ui", "occupants.indent", NULL)) {
+        gint occupants_indent = g_key_file_get_integer(theme, "ui", "occupants.indent", NULL);
+        prefs_set_occupants_indent(occupants_indent);
+    }
+
+    if (g_key_file_has_key(theme, "ui", "roster.size", NULL)) {
+        gint roster_size = g_key_file_get_integer(theme, "ui", "roster.size", NULL);
+        prefs_set_roster_size(roster_size);
+    }
+
+    if (g_key_file_has_key(theme, "ui", "roster.contact.indent", NULL)) {
+        gint contact_indent = g_key_file_get_integer(theme, "ui", "roster.contact.indent", NULL);
+        prefs_set_roster_contact_indent(contact_indent);
+    }
+
+    if (g_key_file_has_key(theme, "ui", "roster.resource.indent", NULL)) {
+        gint resource_indent = g_key_file_get_integer(theme, "ui", "roster.resource.indent", NULL);
+        prefs_set_roster_resource_indent(resource_indent);
+    }
+
+    if (g_key_file_has_key(theme, "ui", "roster.presence.indent", NULL)) {
+        gint presence_indent = g_key_file_get_integer(theme, "ui", "roster.presence.indent", NULL);
+        prefs_set_roster_presence_indent(presence_indent);
+    }
+
+    // load chars from theme and set them to prefs
+    // with custom set functions
     if (g_key_file_has_key(theme, "ui", "occupants.char", NULL)) {
         gchar *ch = g_key_file_get_string(theme, "ui", "occupants.char", NULL);
         if (ch && strlen(ch) > 0) {
             prefs_set_occupants_char(ch[0]);
             g_free(ch);
         }
-    } else {
-        prefs_clear_occupants_char();
-    }
-
-    if (g_key_file_has_key(theme, "ui", "occupants.indent", NULL)) {
-        gint occupants_indent = g_key_file_get_integer(theme, "ui", "occupants.indent", NULL);
-        prefs_set_occupants_indent(occupants_indent);
     }
 
     if (g_key_file_has_key(theme, "ui", "occupants.header.char", NULL)) {
@@ -476,13 +407,6 @@ _load_preferences(void)
             prefs_set_occupants_header_char(ch[0]);
             g_free(ch);
         }
-    } else {
-        prefs_clear_occupants_header_char();
-    }
-
-    if (g_key_file_has_key(theme, "ui", "roster.size", NULL)) {
-        gint roster_size = g_key_file_get_integer(theme, "ui", "roster.size", NULL);
-        prefs_set_roster_size(roster_size);
     }
 
     if (g_key_file_has_key(theme, "ui", "roster.header.char", NULL)) {
@@ -491,8 +415,6 @@ _load_preferences(void)
             prefs_set_roster_header_char(ch[0]);
             g_free(ch);
         }
-    } else {
-        prefs_clear_roster_header_char();
     }
 
     if (g_key_file_has_key(theme, "ui", "roster.contact.char", NULL)) {
@@ -501,8 +423,6 @@ _load_preferences(void)
             prefs_set_roster_contact_char(ch[0]);
             g_free(ch);
         }
-    } else {
-        prefs_clear_roster_contact_char();
     }
 
     if (g_key_file_has_key(theme, "ui", "roster.resource.char", NULL)) {
@@ -521,8 +441,6 @@ _load_preferences(void)
             prefs_set_roster_room_char(ch[0]);
             g_free(ch);
         }
-    } else {
-        prefs_clear_roster_room_char();
     }
 
     if (g_key_file_has_key(theme, "ui", "roster.rooms.private.char", NULL)) {
@@ -531,8 +449,6 @@ _load_preferences(void)
             prefs_set_roster_room_private_char(ch[0]);
             g_free(ch);
         }
-    } else {
-        prefs_clear_roster_room_private_char();
     }
 
     if (g_key_file_has_key(theme, "ui", "roster.private.char", NULL)) {
@@ -541,23 +457,6 @@ _load_preferences(void)
             prefs_set_roster_private_char(ch[0]);
             g_free(ch);
         }
-    } else {
-        prefs_clear_roster_private_char();
-    }
-
-    if (g_key_file_has_key(theme, "ui", "roster.contact.indent", NULL)) {
-        gint contact_indent = g_key_file_get_integer(theme, "ui", "roster.contact.indent", NULL);
-        prefs_set_roster_contact_indent(contact_indent);
-    }
-
-    if (g_key_file_has_key(theme, "ui", "roster.resource.indent", NULL)) {
-        gint resource_indent = g_key_file_get_integer(theme, "ui", "roster.resource.indent", NULL);
-        prefs_set_roster_resource_indent(resource_indent);
-    }
-
-    if (g_key_file_has_key(theme, "ui", "roster.presence.indent", NULL)) {
-        gint presence_indent = g_key_file_get_integer(theme, "ui", "roster.presence.indent", NULL);
-        prefs_set_roster_presence_indent(presence_indent);
     }
 
     if (g_key_file_has_key(theme, "ui", "otr.char", NULL)) {
@@ -584,21 +483,25 @@ _load_preferences(void)
         }
     }
 
+    // load window positions
     if (g_key_file_has_key(theme, "ui", "titlebar.position", NULL) &&
             g_key_file_has_key(theme, "ui", "mainwin.position", NULL) &&
             g_key_file_has_key(theme, "ui", "statusbar.position", NULL) &&
             g_key_file_has_key(theme, "ui", "inputwin.position", NULL)) {
+
         int titlebar_pos = g_key_file_get_integer(theme, "ui", "titlebar.position", NULL);
         int mainwin_pos = g_key_file_get_integer(theme, "ui", "mainwin.position", NULL);
         int statusbar_pos = g_key_file_get_integer(theme, "ui", "statusbar.position", NULL);
         int inputwin_pos = g_key_file_get_integer(theme, "ui", "inputwin.position", NULL);
+
         ProfWinPlacement *placement = prefs_create_profwin_placement(titlebar_pos, mainwin_pos, statusbar_pos, inputwin_pos);
+
         prefs_save_win_placement(placement);
         prefs_free_win_placement(placement);
     }
 }
 
-void
+static void
 _theme_list_dir(const gchar *const dir, GSList **result)
 {
     GDir *themes = g_dir_open(dir, 0, NULL);
@@ -732,6 +635,15 @@ _theme_prep_bgnd(char *setting, char *def, GString *lookup_str)
     g_free(val);
 }
 
+/* return value needs to be freed */
+char*
+theme_get_bkgnd(void)
+{
+    char *val = g_key_file_get_string(theme, "colours", "bkgnd", NULL);
+    return val;
+}
+
+/* gets the foreground color from the theme. or uses the one defined in 'defaults' */
 static void
 _theme_prep_fgnd(char *setting, GString *lookup_str, gboolean *bold)
 {
@@ -770,6 +682,23 @@ theme_free_string(char *str)
     }
 }
 
+int
+theme_hash_attrs(const char *str)
+{
+    color_profile profile = COLOR_PROFILE_DEFAULT;
+
+    char *color_pref = prefs_get_string(PREF_COLOR_NICK);
+    if (strcmp(color_pref, "redgreen") == 0) {
+        profile = COLOR_PROFILE_REDGREEN_BLINDNESS;
+    } else if (strcmp(color_pref, "blue") == 0) {
+        profile = COLOR_PROFILE_BLUE_BLINDNESS;
+    }
+    prefs_free_string(color_pref);
+
+    return COLOR_PAIR(color_pair_cache_hash_str(str, profile));
+}
+
+/* returns the colours (fgnd and bknd) for a certian attribute ie main.text */
 int
 theme_attrs(theme_item_t attrs)
 {
@@ -781,6 +710,7 @@ theme_attrs(theme_item_t attrs)
     // get forground colour
     switch (attrs) {
     case THEME_TEXT:                    _theme_prep_fgnd("main.text",               lookup_str, &bold); break;
+    case THEME_TEXT_HISTORY:            _theme_prep_fgnd("main.text.history",       lookup_str, &bold); break;
     case THEME_TEXT_ME:                 _theme_prep_fgnd("main.text.me",            lookup_str, &bold); break;
     case THEME_TEXT_THEM:               _theme_prep_fgnd("main.text.them",          lookup_str, &bold); break;
     case THEME_SPLASH:                  _theme_prep_fgnd("main.splash",             lookup_str, &bold); break;
@@ -806,6 +736,7 @@ theme_attrs(theme_item_t attrs)
     case THEME_STATUS_TEXT:             _theme_prep_fgnd("statusbar.text",          lookup_str, &bold); break;
     case THEME_STATUS_BRACKET:          _theme_prep_fgnd("statusbar.brackets",      lookup_str, &bold); break;
     case THEME_STATUS_ACTIVE:           _theme_prep_fgnd("statusbar.active",        lookup_str, &bold); break;
+    case THEME_STATUS_CURRENT:          _theme_prep_fgnd("statusbar.current",       lookup_str, &bold); break;
     case THEME_STATUS_NEW:              _theme_prep_fgnd("statusbar.new",           lookup_str, &bold); break;
     case THEME_STATUS_TIME:             _theme_prep_fgnd("statusbar.time",          lookup_str, &bold); break;
     case THEME_ME:                      _theme_prep_fgnd("me",                      lookup_str, &bold); break;
@@ -856,6 +787,7 @@ theme_attrs(theme_item_t attrs)
     case THEME_ROSTER_ROOM_MENTION:     _theme_prep_fgnd("roster.room.mention",     lookup_str, &bold); break;
     case THEME_OCCUPANTS_HEADER:        _theme_prep_fgnd("occupants.header",        lookup_str, &bold); break;
     case THEME_UNTRUSTED:               _theme_prep_fgnd("untrusted",               lookup_str, &bold); break;
+    case THEME_CMD_WINS_UNREAD:         _theme_prep_fgnd("cmd.wins.unread",         lookup_str, &bold); break;
     case THEME_WHITE:                   g_string_append(lookup_str, "white");   bold = FALSE;   break;
     case THEME_WHITE_BOLD:              g_string_append(lookup_str, "white");   bold = TRUE;    break;
     case THEME_GREEN:                   g_string_append(lookup_str, "green");   bold = FALSE;   break;
@@ -896,6 +828,7 @@ theme_attrs(theme_item_t attrs)
     case THEME_STATUS_TEXT:
     case THEME_STATUS_BRACKET:
     case THEME_STATUS_ACTIVE:
+    case THEME_STATUS_CURRENT:
     case THEME_STATUS_NEW:
     case THEME_STATUS_TIME:
         _theme_prep_bgnd("statusbar", "blue", lookup_str);
@@ -906,8 +839,14 @@ theme_attrs(theme_item_t attrs)
     }
 
     // lookup colour pair
-    result = GPOINTER_TO_INT(g_hash_table_lookup(str_to_pair, lookup_str->str));
+    result = color_pair_cache_get(lookup_str->str);
+    if (result < 0) {
+        log_error("Unable to load colour theme");
+        result = 0;
+    }
+
     g_string_free(lookup_str, TRUE);
+
     if (bold) {
         return COLOR_PAIR(result) | A_BOLD;
     } else {
