@@ -1,5 +1,6 @@
 /*
  * theme.h
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -68,6 +69,7 @@ typedef enum {
     THEME_STATUS_TEXT,
     THEME_STATUS_BRACKET,
     THEME_STATUS_ACTIVE,
+    THEME_STATUS_CURRENT,
     THEME_STATUS_NEW,
     THEME_STATUS_TIME,
     THEME_ME,
@@ -135,14 +137,17 @@ typedef enum {
     THEME_BLACK_BOLD,
     THEME_MAGENTA,
     THEME_MAGENTA_BOLD,
+    THEME_TEXT_HISTORY,
+    THEME_CMD_WINS_UNREAD,
 } theme_item_t;
 
 void theme_init(const char *const theme_name);
 void theme_init_colours(void);
-gboolean theme_load(const char *const theme_name);
+gboolean theme_load(const char *const theme_name, gboolean load_theme_prefs);
 gboolean theme_exists(const char *const theme_name);
 GSList* theme_list(void);
 void theme_close(void);
+int theme_hash_attrs(const char *str);
 int theme_attrs(theme_item_t attrs);
 char* theme_get_string(char *str);
 void theme_free_string(char *str);
@@ -150,5 +155,6 @@ theme_item_t theme_main_presence_attrs(const char *const presence);
 theme_item_t theme_roster_unread_presence_attrs(const char *const presence);
 theme_item_t theme_roster_active_presence_attrs(const char *const presence);
 theme_item_t theme_roster_presence_attrs(const char *const presence);
+char* theme_get_bkgnd(void);
 
 #endif
