@@ -1,8 +1,9 @@
 /*
  * server_events.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -49,9 +50,11 @@
 #include "event/common.h"
 #include "plugins/plugins.h"
 #include "ui/window_list.h"
+#include "xmpp/xmpp.h"
 #include "xmpp/muc.h"
 #include "xmpp/chat_session.h"
 #include "xmpp/roster_list.h"
+#include "xmpp/avatar.h"
 
 #ifdef HAVE_LIBOTR
 #include "otr/otr.h"
@@ -67,6 +70,8 @@
 
 #include "ui/ui.h"
 
+static void _clean_incoming_message(ProfMessage *message);
+
 void
 sv_ev_login_account_success(char *account_name, gboolean secured)
 {
@@ -86,6 +91,8 @@ sv_ev_login_account_success(char *account_name, gboolean secured)
     omemo_on_connect(account);
 #endif
 
+    avatar_pep_subscribe();
+
     ui_handle_login_account_success(account, secured);
 
     // attempt to rejoin all rooms
@@ -153,35 +160,33 @@ sv_ev_roster_received(void)
     // send initial presence
     resource_presence_t conn_presence = accounts_get_login_presence(account_name);
     char *last_activity_str = accounts_get_last_activity(account_name);
-    if (last_activity_str) {
-        GDateTime *nowdt = g_date_time_new_now_utc();
+    if (prefs_get_boolean(PREF_LASTACTIVITY) && last_activity_str) {
 
         GTimeVal lasttv;
+        GDateTime *nowdt = g_date_time_new_now_utc();
         gboolean res = g_time_val_from_iso8601(last_activity_str, &lasttv);
+
         if (res) {
             GDateTime *lastdt = g_date_time_new_from_timeval_utc(&lasttv);
             GTimeSpan diff_micros = g_date_time_difference(nowdt, lastdt);
             int diff_secs = (diff_micros / 1000) / 1000;
-            if (prefs_get_boolean(PREF_LASTACTIVITY)) {
-                connection_set_presence_msg(NULL);
-                cl_ev_presence_send(conn_presence, diff_secs);
-            } else {
-                connection_set_presence_msg(NULL);
-                cl_ev_presence_send(conn_presence, 0);
-            }
+
+            connection_set_presence_msg(NULL);
+            cl_ev_presence_send(conn_presence, diff_secs);
+
             g_date_time_unref(lastdt);
         } else {
             connection_set_presence_msg(NULL);
             cl_ev_presence_send(conn_presence, 0);
         }
-
-        free(last_activity_str);
         g_date_time_unref(nowdt);
     } else {
         connection_set_presence_msg(NULL);
         cl_ev_presence_send(conn_presence, 0);
     }
 
+    free(last_activity_str);
+
     const char *fulljid = connection_get_fulljid();
     plugins_on_connect(account_name, fulljid);
 
@@ -286,6 +291,15 @@ sv_ev_room_history(ProfMessage *message)
     }
 }
 
+static void _log_muc(ProfMessage *message)
+{
+    if (message->enc == PROF_MSG_ENC_OMEMO) {
+        groupchat_log_omemo_msg_in(message->jid->barejid, message->jid->resourcepart, message->plain);
+    } else {
+        groupchat_log_msg_in(message->jid->barejid, message->jid->resourcepart, message->plain);
+    }
+}
+
 void
 sv_ev_room_message(ProfMessage *message)
 {
@@ -296,10 +310,10 @@ sv_ev_room_message(ProfMessage *message)
 
     char *mynick = muc_nick(mucwin->roomjid);
 
-    if (message->enc == PROF_MSG_ENC_OMEMO) {
-        groupchat_log_omemo_msg_in(message->jid->barejid, message->jid->resourcepart, message->plain);
-    } else {
-        groupchat_log_msg_in(message->jid->barejid, message->jid->resourcepart, message->plain);
+    // only log message not coming from this client (but maybe same account, different client)
+    // our messages are logged when outgoing
+    if (!(g_strcmp0(mynick, message->jid->resourcepart) == 0 && message_is_sent_by_us(message, TRUE))) {
+        _log_muc(message);
     }
 
     char *old_plain = message->plain;
@@ -318,6 +332,7 @@ sv_ev_room_message(ProfMessage *message)
 
     GList *triggers = prefs_message_get_triggers(message->plain);
 
+    _clean_incoming_message(message);
     mucwin_incoming_msg(mucwin, message, mentions, triggers);
 
     g_slist_free(mentions);
@@ -389,7 +404,10 @@ sv_ev_incoming_private_message(ProfMessage *message)
         ProfWin *window = wins_new_private(message->jid->fulljid);
         privatewin = (ProfPrivateWin*)window;
     }
+
+    _clean_incoming_message(message);
     privwin_incoming_msg(privatewin, message);
+    chat_log_msg_in(message);
 
     plugins_post_priv_message_display(message->jid->fulljid, message->plain);
 
@@ -409,7 +427,10 @@ sv_ev_delayed_private_message(ProfMessage *message)
         ProfWin *window = wins_new_private(message->jid->fulljid);
         privatewin = (ProfPrivateWin*)window;
     }
+
+    _clean_incoming_message(message);
     privwin_incoming_msg(privatewin, message);
+    chat_log_msg_in(message);
 
     plugins_post_priv_message_display(message->jid->fulljid, message->plain);
 
@@ -427,6 +448,15 @@ sv_ev_outgoing_carbon(ProfMessage *message)
 
     chat_state_active(chatwin->state);
 
+    if (message->plain) {
+        if (message->mucuser) {
+            // MUC PM, should have resource (nick) in filename
+            chat_log_msg_out(message->jid->barejid, message->plain, message->jid->resourcepart);
+        } else {
+            chat_log_msg_out(message->jid->barejid, message->plain, NULL);
+        }
+    }
+
 #ifdef HAVE_LIBGPGME
 #ifndef HAVE_OMEMO
     if (message->encrypted) {
@@ -505,13 +535,16 @@ sv_ev_outgoing_carbon(ProfMessage *message)
 
 #ifdef HAVE_LIBGPGME
 static void
-_sv_ev_incoming_pgp(ProfChatWin *chatwin, gboolean new_win, ProfMessage *message)
+_sv_ev_incoming_pgp(ProfChatWin *chatwin, gboolean new_win, ProfMessage *message, gboolean logit)
 {
     message->plain = p_gpg_decrypt(message->encrypted);
     if (message->plain) {
         message->enc = PROF_MSG_ENC_PGP;
+        _clean_incoming_message(message);
         chatwin_incoming_msg(chatwin, message, new_win);
-        chat_log_pgp_msg_in(message);
+        if (logit) {
+            chat_log_pgp_msg_in(message);
+        }
         chatwin->pgp_recv = TRUE;
         p_gpg_free_decrypted(message->plain);
         message->plain = NULL;
@@ -522,6 +555,7 @@ _sv_ev_incoming_pgp(ProfChatWin *chatwin, gboolean new_win, ProfMessage *message
         }
         message->enc = PROF_MSG_ENC_PLAIN;
         message->plain = strdup(message->body);
+        _clean_incoming_message(message);
         chatwin_incoming_msg(chatwin, message, new_win);
         chat_log_msg_in(message);
         chatwin->pgp_recv = FALSE;
@@ -543,6 +577,7 @@ _sv_ev_incoming_otr(ProfChatWin *chatwin, gboolean new_win, ProfMessage *message
             message->enc = PROF_MSG_ENC_PLAIN;
         }
 
+        _clean_incoming_message(message);
         chatwin_incoming_msg(chatwin, message, new_win);
 
         chat_log_otr_msg_in(message);
@@ -555,22 +590,28 @@ _sv_ev_incoming_otr(ProfChatWin *chatwin, gboolean new_win, ProfMessage *message
 
 #ifdef HAVE_OMEMO
 static void
-_sv_ev_incoming_omemo(ProfChatWin *chatwin, gboolean new_win, ProfMessage *message)
+_sv_ev_incoming_omemo(ProfChatWin *chatwin, gboolean new_win, ProfMessage *message, gboolean logit)
 {
+    _clean_incoming_message(message);
     chatwin_incoming_msg(chatwin, message, new_win);
-    chat_log_omemo_msg_in(message);
+    if (logit) {
+        chat_log_omemo_msg_in(message);
+    }
     chatwin->pgp_recv = FALSE;
 }
 #endif
 
 static void
-_sv_ev_incoming_plain(ProfChatWin *chatwin, gboolean new_win, ProfMessage *message)
+_sv_ev_incoming_plain(ProfChatWin *chatwin, gboolean new_win, ProfMessage *message, gboolean logit)
 {
     if (message->body) {
         message->enc = PROF_MSG_ENC_PLAIN;
         message->plain = strdup(message->body);
+        _clean_incoming_message(message);
         chatwin_incoming_msg(chatwin, message, new_win);
-        chat_log_msg_in(message);
+        if (logit) {
+            chat_log_msg_in(message);
+        }
         chatwin->pgp_recv = FALSE;
     }
 }
@@ -601,7 +642,7 @@ sv_ev_incoming_message(ProfMessage *message)
         if (chatwin->is_otr) {
             win_println((ProfWin*)chatwin, THEME_DEFAULT, '-', "PGP encrypted message received whilst in OTR session.");
         } else {
-            _sv_ev_incoming_pgp(chatwin, new_win, message);
+            _sv_ev_incoming_pgp(chatwin, new_win, message, TRUE);
         }
     } else {
         _sv_ev_incoming_otr(chatwin, new_win, message);
@@ -628,9 +669,9 @@ sv_ev_incoming_message(ProfMessage *message)
 #ifdef HAVE_LIBGPGME
 #ifndef HAVE_OMEMO
     if (message->encrypted) {
-        _sv_ev_incoming_pgp(chatwin, new_win, message);
+        _sv_ev_incoming_pgp(chatwin, new_win, message, TRUE);
     } else {
-        _sv_ev_incoming_plain(chatwin, new_win, message);
+        _sv_ev_incoming_plain(chatwin, new_win, message, TRUE);
     }
     rosterwin_roster();
     return;
@@ -646,10 +687,10 @@ sv_ev_incoming_message(ProfMessage *message)
         if (chatwin->is_otr) {
             win_println((ProfWin*)chatwin, THEME_DEFAULT, '-', "PGP encrypted message received whilst in OTR session.");
         } else {
-            _sv_ev_incoming_pgp(chatwin, new_win, message);
+            _sv_ev_incoming_pgp(chatwin, new_win, message, TRUE);
         }
     } else if (message->enc == PROF_MSG_ENC_OMEMO) {
-        _sv_ev_incoming_omemo(chatwin, new_win, message);
+        _sv_ev_incoming_omemo(chatwin, new_win, message, TRUE);
     } else {
         _sv_ev_incoming_otr(chatwin, new_win, message);
     }
@@ -664,7 +705,7 @@ sv_ev_incoming_message(ProfMessage *message)
 #ifndef HAVE_LIBGPGME
 #ifdef HAVE_OMEMO
     if (message->enc == PROF_MSG_ENC_OMEMO) {
-        _sv_ev_incoming_omemo(chatwin, new_win, message);
+        _sv_ev_incoming_omemo(chatwin, new_win, message, TRUE);
     } else {
         _sv_ev_incoming_otr(chatwin, new_win, message);
     }
@@ -679,11 +720,11 @@ sv_ev_incoming_message(ProfMessage *message)
 #ifdef HAVE_LIBGPGME
 #ifdef HAVE_OMEMO
     if (message->encrypted) {
-        _sv_ev_incoming_pgp(chatwin, new_win, message);
+        _sv_ev_incoming_pgp(chatwin, new_win, message, TRUE);
     } else if (message->enc == PROF_MSG_ENC_OMEMO) {
-        _sv_ev_incoming_omemo(chatwin, new_win, message);
+        _sv_ev_incoming_omemo(chatwin, new_win, message, TRUE);
     } else {
-        _sv_ev_incoming_plain(chatwin, new_win, message);
+        _sv_ev_incoming_plain(chatwin, new_win, message, TRUE);
     }
     rosterwin_roster();
     return;
@@ -696,9 +737,9 @@ sv_ev_incoming_message(ProfMessage *message)
 #ifndef HAVE_LIBGPGME
 #ifdef HAVE_OMEMO
     if (message->enc == PROF_MSG_ENC_OMEMO) {
-        _sv_ev_incoming_omemo(chatwin, new_win, message);
+        _sv_ev_incoming_omemo(chatwin, new_win, message, TRUE);
     } else {
-        _sv_ev_incoming_plain(chatwin, new_win, message);
+        _sv_ev_incoming_plain(chatwin, new_win, message, TRUE);
     }
     rosterwin_roster();
     return;
@@ -710,7 +751,7 @@ sv_ev_incoming_message(ProfMessage *message)
 #ifndef HAVE_LIBOTR
 #ifndef HAVE_LIBGPGME
 #ifndef HAVE_OMEMO
-    _sv_ev_incoming_plain(chatwin, new_win, message);
+    _sv_ev_incoming_plain(chatwin, new_win, message, TRUE);
     rosterwin_roster();
     return;
 #endif
@@ -739,9 +780,9 @@ sv_ev_incoming_carbon(ProfMessage *message)
 #ifdef HAVE_LIBGPGME
 #ifndef HAVE_OMEMO
     if (message->encrypted) {
-        _sv_ev_incoming_pgp(chatwin, new_win, message);
+        _sv_ev_incoming_pgp(chatwin, new_win, message, FALSE);
     } else {
-        _sv_ev_incoming_plain(chatwin, new_win, message);
+        _sv_ev_incoming_plain(chatwin, new_win, message, FALSE);
     }
     rosterwin_roster();
     return;
@@ -751,11 +792,11 @@ sv_ev_incoming_carbon(ProfMessage *message)
 #ifdef HAVE_LIBGPGME
 #ifdef HAVE_OMEMO
     if (message->encrypted) {
-        _sv_ev_incoming_pgp(chatwin, new_win, message);
+        _sv_ev_incoming_pgp(chatwin, new_win, message, FALSE);
     } else if (message->enc == PROF_MSG_ENC_OMEMO) {
-        _sv_ev_incoming_omemo(chatwin, new_win, message);
+        _sv_ev_incoming_omemo(chatwin, new_win, message, FALSE);
     } else {
-        _sv_ev_incoming_plain(chatwin, new_win, message);
+        _sv_ev_incoming_plain(chatwin, new_win, message, FALSE);
     }
     rosterwin_roster();
     return;
@@ -765,9 +806,9 @@ sv_ev_incoming_carbon(ProfMessage *message)
 #ifndef HAVE_LIBGPGME
 #ifdef HAVE_OMEMO
     if (message->enc == PROF_MSG_ENC_OMEMO) {
-        _sv_ev_incoming_omemo(chatwin, new_win, message);
+        _sv_ev_incoming_omemo(chatwin, new_win, message, FALSE);
     } else {
-        _sv_ev_incoming_plain(chatwin, new_win, message);
+        _sv_ev_incoming_plain(chatwin, new_win, message, FALSE);
     }
     rosterwin_roster();
     return;
@@ -776,7 +817,7 @@ sv_ev_incoming_carbon(ProfMessage *message)
 
 #ifndef HAVE_LIBGPGME
 #ifndef HAVE_OMEMO
-    _sv_ev_incoming_plain(chatwin, new_win, message);
+    _sv_ev_incoming_plain(chatwin, new_win, message, FALSE);
     rosterwin_roster();
     return;
 #endif
@@ -863,9 +904,13 @@ sv_ev_subscription(const char *barejid, jabber_subscr_t type)
         }
         break;
     case PRESENCE_SUBSCRIBED:
-        cons_show("Subscription received from %s", barejid);
         log_info("Subscription received from %s", barejid);
-        ui_print_system_msg_from_recipient(barejid, "Subscribed");
+        cons_show("Subscription received from %s", barejid);
+
+        PContact contact = roster_get_contact(barejid);
+        if (contact == NULL) {
+            ui_print_system_msg_from_recipient(barejid, "Subscribed");
+        }
         break;
     case PRESENCE_UNSUBSCRIBED:
         cons_show("%s deleted subscription", barejid);
@@ -1154,6 +1199,10 @@ sv_ev_muc_occupant_online(const char *const room, const char *const nick, const
 
     gboolean updated = muc_roster_add(room, nick, jid, role, affiliation, show, status);
 
+    if (jid != NULL && affiliation != NULL) {
+        muc_members_update(room, jid, affiliation);
+    }
+
     // not yet finished joining room
     if (!muc_roster_complete(room)) {
         return;
@@ -1379,7 +1428,28 @@ sv_ev_bookmark_autojoin(Bookmark *bookmark)
     if (!muc_active(bookmark->barejid)) {
         presence_join_room(bookmark->barejid, nick, bookmark->password);
         muc_join(bookmark->barejid, nick, bookmark->password, TRUE);
+        iq_room_affiliation_list(bookmark->barejid, "member", false);
+        iq_room_affiliation_list(bookmark->barejid, "admin", false);
+        iq_room_affiliation_list(bookmark->barejid, "owner", false);
     }
 
     free(nick);
 }
+
+static void
+_cut(ProfMessage *message, const char *cut)
+{
+    if (strstr(message->plain, cut)) {
+        char **split = g_strsplit(message->plain, cut, -1);
+        free(message->plain);
+        message->plain = g_strjoinv("", split);
+        g_strfreev(split);
+    }
+}
+
+static void
+_clean_incoming_message(ProfMessage *message)
+{
+    _cut(message, "\u200E");
+    _cut(message, "\u200F");
+}
