@@ -1,5 +1,6 @@
 /*
  * log.h
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -70,10 +71,10 @@ void log_stderr_handler(void);
 
 void chat_log_init(void);
 
-void chat_log_msg_out(const char *const barejid, const char *const msg);
-void chat_log_otr_msg_out(const char *const barejid, const char *const msg);
-void chat_log_pgp_msg_out(const char *const barejid, const char *const msg);
-void chat_log_omemo_msg_out(const char *const barejid, const char *const msg);
+void chat_log_msg_out(const char *const barejid, const char *const msg, const char *resource);
+void chat_log_otr_msg_out(const char *const barejid, const char *const msg, const char *resource);
+void chat_log_pgp_msg_out(const char *const barejid, const char *const msg, const char *resource);
+void chat_log_omemo_msg_out(const char *const barejid, const char *const msg, const char *resource);
 
 void chat_log_msg_in(ProfMessage *message);
 void chat_log_otr_msg_in(ProfMessage *message);
