@@ -1,8 +1,9 @@
 /*
  * main.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -61,6 +62,7 @@
 static gboolean version = FALSE;
 static char *log = "INFO";
 static char *account_name = NULL;
+static char *config_file = NULL;
 
 int
 main(int argc, char **argv)
@@ -75,6 +77,7 @@ main(int argc, char **argv)
         { "version", 'v', 0, G_OPTION_ARG_NONE, &version, "Show version information", NULL },
         { "account", 'a', 0, G_OPTION_ARG_STRING, &account_name, "Auto connect to an account on startup" },
         { "log",'l', 0, G_OPTION_ARG_STRING, &log, "Set logging levels, DEBUG, INFO (default), WARN, ERROR", "LEVEL" },
+        { "config",'c', 0, G_OPTION_ARG_STRING, &config_file, "Use an alternative configuration file", NULL },
         { NULL }
     };
 
@@ -103,8 +106,9 @@ main(int argc, char **argv)
             g_print("Profanity, version %s\n", PACKAGE_VERSION);
         }
 
-        g_print("Copyright (C) 2012 - 2019 James Booth <%s>.\n", PACKAGE_BUGREPORT);
-        g_print("Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>.\n");
+        // lets use fixed email instead of PACKAGE_BUGREPORT
+        g_print("Copyright (C) 2012 - 2019 James Booth <boothj5web@gmail.com>.\n");
+        g_print("Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>.\n");
         g_print("License GPLv3+: GNU GPL version 3 or later <https://www.gnu.org/licenses/gpl.html>\n");
         g_print("\n");
         g_print("This is free software; you are free to change and redistribute it.\n");
@@ -169,7 +173,7 @@ main(int argc, char **argv)
         return 0;
     }
 
-    prof_run(log, account_name);
+    prof_run(log, account_name, config_file);
 
     return 0;
 }
