@@ -1,8 +1,9 @@
 /*
  * omemo.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2019 Paul Fariello <paul@fariello.eu>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -107,7 +108,7 @@ struct omemo_context_t {
     GHashTable *known_devices;
     GString *known_devices_filename;
     GKeyFile *known_devices_keyfile;
-    Autocomplete fingerprint_ac;
+    GHashTable *fingerprint_ac;
 };
 
 static omemo_context omemo_ctx;
@@ -124,14 +125,14 @@ omemo_init(void)
     pthread_mutexattr_settype(&omemo_ctx.attr, PTHREAD_MUTEX_RECURSIVE);
     pthread_mutex_init(&omemo_ctx.lock, &omemo_ctx.attr);
 
-    omemo_ctx.fingerprint_ac = autocomplete_new();
+    omemo_ctx.fingerprint_ac = g_hash_table_new_full(g_str_hash, g_str_equal, free, (GDestroyNotify)autocomplete_free);
 }
 
 void
 omemo_close(void)
 {
     if (omemo_ctx.fingerprint_ac) {
-        autocomplete_free(omemo_ctx.fingerprint_ac);
+        g_hash_table_destroy(omemo_ctx.fingerprint_ac);
         omemo_ctx.fingerprint_ac = NULL;
     }
 }
@@ -325,7 +326,7 @@ omemo_generate_crypto_materials(ProfAccount *account)
         return;
     }
 
-    log_info("Generate long term OMEMO cryptography metarials");
+    log_info("Generate long term OMEMO cryptography materials");
 
     /* Device ID */
     gcry_randomize(&omemo_ctx.device_id, 4, GCRY_VERY_STRONG_RANDOM);
@@ -420,19 +421,14 @@ omemo_start_session(const char *const barejid)
 void
 omemo_start_muc_sessions(const char *const roomjid)
 {
-    GList *roster = muc_roster(roomjid);
+    GList *members = muc_members(roomjid);
     GList *iter;
-    for (iter = roster; iter != NULL; iter = iter->next) {
-        Occupant *occupant = (Occupant *)iter->data;
-        if (occupant->jid != NULL) {
-            Jid *jid = jid_create(occupant->jid);
-            omemo_start_session(jid->barejid);
-            jid_destroy(jid);
-        } else {
-            log_error("OMEMO: cannot get real jid for %s in %s", occupant->nick, roomjid);
-        }
+    for (iter = members; iter != NULL; iter = iter->next) {
+        Jid *jid = jid_create(iter->data);
+        omemo_start_session(jid->barejid);
+        jid_destroy(jid);
     }
-    g_list_free(roster);
+    g_list_free(members);
 }
 
 gboolean
@@ -711,19 +707,14 @@ omemo_on_message_send(ProfWin *win, const char *const message, gboolean request_
     if (muc) {
         ProfMucWin *mucwin = (ProfMucWin *)win;
         assert(mucwin->memcheck == PROFMUCWIN_MEMCHECK);
-        GList *roster = muc_roster(mucwin->roomjid);
+        GList *members = muc_members(mucwin->roomjid);
         GList *iter;
-        for (iter = roster; iter != NULL; iter = iter->next) {
-            Occupant *occupant = (Occupant *)iter->data;
-            Jid *jid = jid_create(occupant->jid);
-            if (!jid->barejid) {
-                log_warning("OMEMO: missing barejid for MUC %s occupant %s", mucwin->roomjid, occupant->nick);
-            } else {
-                recipients = g_list_append(recipients, strdup(jid->barejid));
-            }
+        for (iter = members; iter != NULL; iter = iter->next) {
+            Jid *jid = jid_create(iter->data);
+            recipients = g_list_append(recipients, strdup(jid->barejid));
             jid_destroy(jid);
         }
-        g_list_free(roster);
+        g_list_free(members);
     } else {
         ProfChatWin *chatwin = (ProfChatWin *)win;
         assert(chatwin->memcheck == PROFCHATWIN_MEMCHECK);
@@ -861,7 +852,7 @@ omemo_on_message_recv(const char *const from_jid, uint32_t sid,
     }
 
     if (!key) {
-        log_warning("OMEMO: Received a message with no corresponding key");
+        log_warning("OMEMO: received a message with no corresponding key");
         goto out;
     }
 
@@ -964,7 +955,7 @@ omemo_on_message_recv(const char *const from_jid, uint32_t sid,
     size_t plaintext_len = payload_len;
     plaintext = malloc(plaintext_len + 1);
     res = aes128gcm_decrypt(plaintext, &plaintext_len, payload, payload_len, iv,
-        signal_buffer_data(plaintext_key),
+        iv_len, signal_buffer_data(plaintext_key),
         signal_buffer_data(plaintext_key) + AES128_GCM_KEY_LENGTH);
     signal_buffer_free(plaintext_key);
     if (res != 0) {
@@ -1309,15 +1300,27 @@ omemo_key_free(omemo_key_t *key)
 }
 
 char*
-omemo_fingerprint_autocomplete(const char *const search_str, gboolean previous)
+omemo_fingerprint_autocomplete(const char *const search_str, gboolean previous, void *context)
 {
-    return autocomplete_complete(omemo_ctx.fingerprint_ac, search_str, FALSE, previous);
+    Autocomplete ac = g_hash_table_lookup(omemo_ctx.fingerprint_ac, context);
+    if (ac != NULL) {
+        return autocomplete_complete(ac, search_str, FALSE, previous);
+    } else {
+        return NULL;
+    }
 }
 
 void
 omemo_fingerprint_autocomplete_reset(void)
 {
-    autocomplete_reset(omemo_ctx.fingerprint_ac);
+    gpointer value;
+    GHashTableIter iter;
+    g_hash_table_iter_init(&iter, omemo_ctx.fingerprint_ac);
+
+    while (g_hash_table_iter_next(&iter, NULL, &value)) {
+        Autocomplete ac = value;
+        autocomplete_reset(ac);
+    }
 }
 
 gboolean
@@ -1605,8 +1608,14 @@ _cache_device_identity(const char *const jid, uint32_t device_id, ec_public_key
     g_free(device_id_str);
     omemo_known_devices_keyfile_save();
 
+    Autocomplete ac = g_hash_table_lookup(omemo_ctx.fingerprint_ac, jid);
+    if (ac == NULL) {
+        ac = autocomplete_new();
+        g_hash_table_insert(omemo_ctx.fingerprint_ac, strdup(jid), ac);
+    }
+
     char *formatted_fingerprint = omemo_format_fingerprint(fingerprint);
-    autocomplete_add(omemo_ctx.fingerprint_ac, formatted_fingerprint);
+    autocomplete_add(ac, formatted_fingerprint);
     free(formatted_fingerprint);
     free(fingerprint);
 }
