@@ -1,5 +1,6 @@
 /*
  * otr.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -346,7 +347,7 @@ otr_on_message_send(ProfChatWin *chatwin, const char *const message, gboolean re
         char *encrypted = otr_encrypt_message(chatwin->barejid, message);
         if (encrypted) {
             id = message_send_chat_otr(chatwin->barejid, encrypted, request_receipt);
-            chat_log_otr_msg_out(chatwin->barejid, message);
+            chat_log_otr_msg_out(chatwin->barejid, message, NULL);
             chatwin_outgoing_msg(chatwin, message, id, PROF_MSG_ENC_OTR, request_receipt);
             otr_free_message(encrypted);
             free(id);
@@ -368,7 +369,7 @@ otr_on_message_send(ProfChatWin *chatwin, const char *const message, gboolean re
         char *otr_tagged_msg = otr_tag_message(message);
         id = message_send_chat_otr(chatwin->barejid, otr_tagged_msg, request_receipt);
         chatwin_outgoing_msg(chatwin, message, id, PROF_MSG_ENC_PLAIN, request_receipt);
-        chat_log_msg_out(chatwin->barejid, message);
+        chat_log_msg_out(chatwin->barejid, message, NULL);
         free(otr_tagged_msg);
         free(id);
         return TRUE;
