@@ -1,5 +1,6 @@
 /*
  * gpg.h
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -67,7 +68,7 @@ void p_gpg_verify(const char *const barejid, const char *const sign);
 char* p_gpg_encrypt(const char *const barejid, const char *const message, const char *const fp);
 char* p_gpg_decrypt(const char *const cipher);
 void p_gpg_free_decrypted(char *decrypted);
-char* p_gpg_autocomplete_key(const char *const search_str, gboolean previous);
+char* p_gpg_autocomplete_key(const char *const search_str, gboolean previous, void *context);
 void p_gpg_autocomplete_key_reset(void);
 char* p_gpg_format_fp_str(char *fp);
 
