@@ -1,5 +1,6 @@
 /*
  * python_api.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -32,15 +33,13 @@
  *
  */
 
-#include "config.h"
-
+#undef _XOPEN_SOURCE
 #include <Python.h>
+
+#include "config.h"
 #include <frameobject.h>
-
 #include <stdlib.h>
-
 #include <glib.h>
-
 #include "log.h"
 #include "plugins/api.h"
 #include "plugins/python_api.h"
