@@ -1,5 +1,6 @@
 /*
  * python_plugins.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -32,6 +33,7 @@
  *
  */
 
+#undef _XOPEN_SOURCE
 #include <Python.h>
 
 #include "log.h"
