@@ -1,8 +1,9 @@
 /*
  * profanity.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -85,7 +86,7 @@
 #include "omemo/omemo.h"
 #endif
 
-static void _init(char *log_level);
+static void _init(char *log_level, char *config_file);
 static void _shutdown(void);
 static void _connect_default(const char * const account);
 
@@ -93,9 +94,9 @@ static gboolean cont = TRUE;
 static gboolean force_quit = FALSE;
 
 void
-prof_run(char *log_level, char *account_name)
+prof_run(char *log_level, char *account_name, char *config_file)
 {
-    _init(log_level);
+    _init(log_level, config_file);
     plugins_on_start();
     _connect_default(account_name);
 
@@ -156,7 +157,7 @@ _connect_default(const char *const account)
 }
 
 static void
-_init(char *log_level)
+_init(char *log_level, char *config_file)
 {
     setlocale(LC_ALL, "");
     // ignore SIGPIPE
@@ -171,7 +172,7 @@ _init(char *log_level)
     pthread_mutex_lock(&lock);
     files_create_directories();
     log_level_t prof_log_level = log_level_from_string(log_level);
-    prefs_load();
+    prefs_load(config_file);
     log_init(prof_log_level);
     log_stderr_init(PROF_LEVEL_ERROR);
     if (strcmp(PACKAGE_STATUS, "development") == 0) {
