@@ -1,5 +1,6 @@
 /*
  * parser.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -368,6 +369,7 @@ get_start(const char *const string, int tokens)
             int len = g_unichar_to_utf8(curr_uni, uni_char);
             uni_char[len] = '\0';
             g_string_append(result, uni_char);
+            free(uni_char);
         }
         if (curr_uni == ' ') {
             if (!in_quotes) {
@@ -414,6 +416,7 @@ parse_options(gchar **args, gchar **opt_keys, gboolean *res)
         // check if option valid
         if (g_list_find_custom(keys, args[curr], (GCompareFunc)g_strcmp0) == NULL) {
             *res = FALSE;
+            g_list_free(found_keys);
             g_list_free(keys);
             return options;
         }
@@ -421,6 +424,7 @@ parse_options(gchar **args, gchar **opt_keys, gboolean *res)
         // check if duplicate
         if (g_list_find_custom(found_keys, args[curr], (GCompareFunc)g_strcmp0)) {
             *res = FALSE;
+            g_list_free(found_keys);
             g_list_free(keys);
             return options;
         }
@@ -428,6 +432,7 @@ parse_options(gchar **args, gchar **opt_keys, gboolean *res)
         // check value given
         if (args[curr+1] == NULL) {
             *res = FALSE;
+            g_list_free(found_keys);
             g_list_free(keys);
             return options;
         }
