@@ -1,5 +1,6 @@
 /*
  * buffer.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -80,7 +81,7 @@ buffer_free(ProfBuff buffer)
 
 void
 buffer_append(ProfBuff buffer, const char show_char, int pad_indent, GDateTime *time,
-    int flags, theme_item_t theme_item, const char *const from, const char *const message, DeliveryReceipt *receipt)
+    int flags, theme_item_t theme_item, const char *const from, const char *const message, DeliveryReceipt *receipt, const char *const id)
 {
     ProfBuffEntry *e = malloc(sizeof(struct prof_buff_entry_t));
     e->show_char = show_char;
@@ -91,6 +92,11 @@ buffer_append(ProfBuff buffer, const char show_char, int pad_indent, GDateTime *
     e->from = from ? strdup(from) : NULL;
     e->message = strdup(message);
     e->receipt = receipt;
+    if (id) {
+        e->id = strdup(id);
+    } else {
+        e->id = NULL;
+    }
 
     if (g_slist_length(buffer->entries) == BUFF_SIZE) {
         _free_entry(buffer->entries->data);
@@ -100,13 +106,26 @@ buffer_append(ProfBuff buffer, const char show_char, int pad_indent, GDateTime *
     buffer->entries = g_slist_append(buffer->entries, e);
 }
 
+void
+buffer_remove_entry_by_id(ProfBuff buffer, const char *const id)
+{
+    GSList *entries = buffer->entries;
+    while (entries) {
+        ProfBuffEntry *entry = entries->data;
+        if (entry->id && (g_strcmp0(entry->id, id) == 0)) {
+            buffer->entries = g_slist_delete_link(buffer->entries, entries);
+        }
+        entries = g_slist_next(entries);
+    }
+}
+
 gboolean
 buffer_mark_received(ProfBuff buffer, const char *const id)
 {
     GSList *entries = buffer->entries;
     while (entries) {
         ProfBuffEntry *entry = entries->data;
-        if (entry->receipt && g_strcmp0(entry->receipt->id, id) == 0) {
+        if (entry->receipt && g_strcmp0(entry->id, id) == 0) {
             if (!entry->receipt->received) {
                 entry->receipt->received = TRUE;
                 return TRUE;
@@ -131,7 +150,7 @@ buffer_get_entry_by_id(ProfBuff buffer, const char *const id)
     GSList *entries = buffer->entries;
     while (entries) {
         ProfBuffEntry *entry = entries->data;
-        if (entry->receipt && g_strcmp0(entry->receipt->id, id) == 0) {
+        if (g_strcmp0(entry->id, id) == 0) {
             return entry;
         }
         entries = g_slist_next(entries);
@@ -145,10 +164,8 @@ _free_entry(ProfBuffEntry *entry)
 {
     free(entry->message);
     free(entry->from);
+    free(entry->id);
+    free(entry->receipt);
     g_date_time_unref(entry->time);
-    if (entry->receipt) {
-        free(entry->receipt->id);
-        free(entry->receipt);
-    }
     free(entry);
 }
