@@ -1,8 +1,9 @@
 /*
  * console.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -413,8 +414,8 @@ cons_about(void)
         }
     }
 
-    win_println(console, THEME_DEFAULT, '-', "Copyright (C) 2012 - 2019 James Booth <%s>.", PACKAGE_BUGREPORT);
-    win_println(console, THEME_DEFAULT, '-', "Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>.");
+    win_println(console, THEME_DEFAULT, '-', "Copyright (C) 2012 - 2019 James Booth <boothj5web@gmail.com>.");
+    win_println(console, THEME_DEFAULT, '-', "Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>.");
     win_println(console, THEME_DEFAULT, '-', "License GPLv3+: GNU GPL version 3 or later <https://www.gnu.org/licenses/gpl.html>");
     win_println(console, THEME_DEFAULT, '-', "");
     win_println(console, THEME_DEFAULT, '-', "This is free software; you are free to change and redistribute it.");
@@ -498,7 +499,11 @@ cons_show_wins(gboolean unread)
 
     GSList *curr = window_strings;
     while (curr) {
-        win_println(console, THEME_DEFAULT, '-', "%s", curr->data);
+        if (g_strstr_len(curr->data, strlen(curr->data), " unread") > 0) {
+            win_println(console, THEME_CMD_WINS_UNREAD, '-', "%s", curr->data);
+        } else {
+            win_println(console, THEME_DEFAULT, '-', "%s", curr->data);
+        }
         curr = g_slist_next(curr);
     }
     g_slist_free_full(window_strings, free);
@@ -826,7 +831,7 @@ cons_show_room_invite(const char *const invitor, const char * const room, const
     }
 
     cons_show("Use '/join %s' to accept the invitation", room);
-    cons_show("Use '/decline %s' to decline the invitation", room);
+    cons_show("Use '/invite decline %s' to decline the invitation", room);
 
     if (prefs_get_boolean(PREF_NOTIFY_INVITE)) {
         notify_invite(display_from, room, reason);
@@ -1126,13 +1131,37 @@ cons_wrap_setting(void)
 }
 
 void
-cons_encwarn_setting(void)
+cons_titlebar_setting(void)
 {
-    if (prefs_get_boolean(PREF_ENC_WARN)) {
-        cons_show("Warn unencrypted (/encwarn)         : ON");
+    cons_winpos_setting();
+
+    if (prefs_get_boolean(PREF_TLS_SHOW)) {
+        cons_show("TLS show (/titlebar)                : ON");
     } else {
-        cons_show("Warn unencrypted (/encwarn)         : OFF");
+        cons_show("TLS show (/titlebar)                : OFF");
     }
+
+    if (prefs_get_boolean(PREF_ENC_WARN)) {
+        cons_show("Warn unencrypted (/titlebar)        : ON");
+    } else {
+        cons_show("Warn unencrypted (/titlebar)        : OFF");
+    }
+
+    if (prefs_get_boolean(PREF_RESOURCE_TITLE)) {
+        cons_show("Resource show (/titlebar)           : ON");
+    } else {
+        cons_show("Resource show (/titlebar)           : OFF");
+    }
+
+    if (prefs_get_boolean(PREF_PRESENCE)) {
+        cons_show("Titlebar presence (/titlebar)       : ON");
+    } else {
+        cons_show("Titlebar presence (/titlebar)       : OFF");
+    }
+
+    char *muctitle = prefs_get_string(PREF_TITLEBAR_MUC_TITLE);
+    cons_show("MUC window title (/titlebar)        : %s", muctitle);
+    prefs_free_string(muctitle);
 }
 
 void
@@ -1151,16 +1180,6 @@ cons_console_setting(void)
     prefs_free_string(privsetting);
 }
 
-void
-cons_tlsshow_setting(void)
-{
-    if (prefs_get_boolean(PREF_TLS_SHOW)) {
-        cons_show("TLS show (/tls)                     : ON");
-    } else {
-        cons_show("TLS show (/tls)                     : OFF");
-    }
-}
-
 void
 cons_presence_setting(void)
 {
@@ -1511,6 +1530,10 @@ cons_roster_setting(void)
     cons_show("Roster rooms by (/roster)           : %s", rooms_by);
     prefs_free_string(rooms_by);
 
+    char *rooms_use = prefs_get_string(PREF_ROSTER_ROOMS_USE_AS_NAME);
+    cons_show("Roster rooms use (/roster)          : %s", rooms_use);
+    prefs_free_string(rooms_use);
+
     char *rooms_order = prefs_get_string(PREF_ROSTER_ROOMS_ORDER);
     cons_show("Roster rooms order (/roster)        : %s", rooms_order);
     prefs_free_string(rooms_order);
@@ -1552,10 +1575,9 @@ cons_show_ui_prefs(void)
     cons_roster_setting();
     cons_privileges_setting();
     cons_wintitle_setting();
-    cons_encwarn_setting();
     cons_presence_setting();
     cons_inpblock_setting();
-    cons_tlsshow_setting();
+    cons_titlebar_setting();
     cons_statusbar_setting();
 
     cons_alert();
@@ -1829,21 +1851,17 @@ cons_log_setting(void)
 }
 
 void
-cons_chlog_setting(void)
+cons_logging_setting(void)
 {
     if (prefs_get_boolean(PREF_CHLOG))
-        cons_show("Chat logging (/chlog)       : ON");
+        cons_show("Chat logging (/logging chat)        : ON");
     else
-        cons_show("Chat logging (/chlog)       : OFF");
-}
+        cons_show("Chat logging (/logging chat)        : OFF");
 
-void
-cons_grlog_setting(void)
-{
     if (prefs_get_boolean(PREF_GRLOG))
-        cons_show("Groupchat logging (/grlog)  : ON");
+        cons_show("Groupchat logging (/logging group)  : ON");
     else
-        cons_show("Groupchat logging (/grlog)  : OFF");
+        cons_show("Groupchat logging (/logging group)  : OFF");
 }
 
 void
@@ -1852,8 +1870,7 @@ cons_show_log_prefs(void)
     cons_show("Logging preferences:");
     cons_show("");
     cons_log_setting();
-    cons_chlog_setting();
-    cons_grlog_setting();
+    cons_logging_setting();
 
     cons_alert();
 }
@@ -1959,6 +1976,51 @@ cons_autoping_setting(void)
     }
 }
 
+void
+cons_color_setting(void)
+{
+    char *color_pref = prefs_get_string(PREF_COLOR_NICK);
+
+    if (!color_pref) {
+        cons_show("Consistent color generation for nicks (/color)                     : OFF");
+        return;
+    }
+
+    if (strcmp(color_pref, "true") == 0) {
+        cons_show("Consistent color generation for nicks (/color)                     : ON");
+    } else if (strcmp(color_pref, "redgreen") == 0) {
+        cons_show("Consistent color generation for nicks (/color)                     : REDGREEN");
+    } else if (strcmp(color_pref, "blue") == 0) {
+        cons_show("Consistent color generation for nicks (/color)                     : BLUE");
+    } else {
+        cons_show("Consistent color generation for nicks (/color)                     : OFF");
+    }
+
+    prefs_free_string(color_pref);
+
+    if (prefs_get_boolean(PREF_ROSTER_COLOR_NICK)) {
+        cons_show("Consistent color generation in roster (/roster color)              : ON");
+    } else {
+        cons_show("Consistent color generation in roster (/roster color)              : OFF");
+    }
+
+    if (prefs_get_boolean(PREF_OCCUPANTS_COLOR_NICK)) {
+        cons_show("Consistent color generation for occupants (/occupants color)       : ON");
+    } else {
+        cons_show("Consistent color generation for occupants (/occupants color)       : OFF");
+    }
+}
+
+void
+cons_os_setting(void)
+{
+    if (prefs_get_boolean(PREF_REVEAL_OS)) {
+        cons_show("Reveal OS name when asked for software version (XEP-0092) (/os)    : ON");
+    } else {
+        cons_show("Reveal OS name when asked for software version (XEP-0092) (/os)    : OFF");
+    }
+}
+
 void
 cons_show_connection_prefs(void)
 {
@@ -2313,6 +2375,7 @@ cons_theme_properties(void)
     _cons_theme_bar_prop(THEME_STATUS_TEXT, "statusbar.text");
     _cons_theme_bar_prop(THEME_STATUS_BRACKET, "statusbar.brackets");
     _cons_theme_bar_prop(THEME_STATUS_ACTIVE, "statusbar.active");
+    _cons_theme_bar_prop(THEME_STATUS_CURRENT, "statusbar.current");
     _cons_theme_bar_prop(THEME_STATUS_NEW, "statusbar.new");
     _cons_theme_bar_prop(THEME_STATUS_TIME, "statusbar.time");
 
@@ -2330,6 +2393,7 @@ cons_theme_properties(void)
     _cons_theme_prop(THEME_TEXT_ME, "main.text.me");
     _cons_theme_prop(THEME_THEM, "them");
     _cons_theme_prop(THEME_TEXT_THEM, "main.text.them");
+    _cons_theme_prop(THEME_TEXT_HISTORY, "main.text.history");
 
     _cons_theme_prop(THEME_CHAT, "chat");
     _cons_theme_prop(THEME_ONLINE, "online");
@@ -2428,6 +2492,13 @@ cons_theme_colours(void)
     win_print(console,      THEME_BLACK, '-',   " black   ");
     win_appendln(console,   THEME_BLACK_BOLD,   " bold_black");
 
+    if (COLORS >= 256) {
+        cons_show("Your terminal supports 256 colours.");
+        cons_show("But only basic colours are printed here.");
+        cons_show("To use them use their Xterm colour name.");
+        cons_show("See https://jonasjacek.github.io/colors/");
+    }
+
     cons_show("");
 }
 
