@@ -1,5 +1,6 @@
 /*
  * core.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -363,7 +364,7 @@ void
 ui_handle_login_account_success(ProfAccount *account, gboolean secured)
 {
     if (account->theme) {
-        if (theme_load(account->theme)) {
+        if (theme_load(account->theme, false)) {
             ui_load_colours();
             if (prefs_get_boolean(PREF_ROSTER)) {
                 ui_show_roster();
@@ -461,7 +462,6 @@ ui_invalid_command_usage(const char *const cmd, void (*setting_func)(void))
     if (setting_func) {
         cons_show("");
         (*setting_func)();
-        cons_show(msg->str);
     } else {
         cons_show("");
         cons_show(msg->str);
@@ -651,16 +651,41 @@ ui_focus_win(ProfWin *window)
     }
 
     ProfWin *old_current = wins_get_current();
+
     if (old_current->type == WIN_CONFIG) {
         ProfConfWin *confwin = (ProfConfWin*)old_current;
         cmd_ac_remove_form_fields(confwin->form);
     }
-
     if (window->type == WIN_CONFIG) {
         ProfConfWin *confwin = (ProfConfWin*)window;
         cmd_ac_add_form_fields(confwin->form);
     }
 
+    // check for trackbar last position separator
+    switch (old_current->type)
+    {
+    case WIN_CHAT:
+    {
+        ProfChatWin *chatwin = (ProfChatWin*)old_current;
+        win_remove_entry_message(old_current, chatwin->barejid);
+        break;
+    }
+    case WIN_MUC:
+    {
+        ProfMucWin *mucwin = (ProfMucWin*)old_current;
+        win_remove_entry_message(old_current, mucwin->roomjid);
+        break;
+    }
+    case WIN_PRIVATE:
+    {
+        ProfPrivateWin *privwin = (ProfPrivateWin*)old_current;
+        win_remove_entry_message(old_current, privwin->fulljid);
+        break;
+    }
+    default:
+        break;
+    }
+
     int i = wins_get_num(window);
     wins_set_current_by_num(i);
 
