@@ -1,5 +1,6 @@
 /*
  * inputwin.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -109,13 +110,25 @@ static int _inp_rl_win_7_handler(int count, int key);
 static int _inp_rl_win_8_handler(int count, int key);
 static int _inp_rl_win_9_handler(int count, int key);
 static int _inp_rl_win_0_handler(int count, int key);
+static int _inp_rl_win_11_handler(int count, int key);
+static int _inp_rl_win_12_handler(int count, int key);
+static int _inp_rl_win_13_handler(int count, int key);
+static int _inp_rl_win_14_handler(int count, int key);
+static int _inp_rl_win_15_handler(int count, int key);
+static int _inp_rl_win_16_handler(int count, int key);
+static int _inp_rl_win_17_handler(int count, int key);
+static int _inp_rl_win_18_handler(int count, int key);
+static int _inp_rl_win_19_handler(int count, int key);
+static int _inp_rl_win_20_handler(int count, int key);
 static int _inp_rl_win_prev_handler(int count, int key);
 static int _inp_rl_win_next_handler(int count, int key);
+static int _inp_rl_win_next_unread_handler(int count, int key);
 static int _inp_rl_win_pageup_handler(int count, int key);
 static int _inp_rl_win_pagedown_handler(int count, int key);
 static int _inp_rl_subwin_pageup_handler(int count, int key);
 static int _inp_rl_subwin_pagedown_handler(int count, int key);
 static int _inp_rl_startup_hook(void);
+static int _inp_rl_down_arrow_handler(int count, int key);
 
 void
 create_input_window(void)
@@ -381,8 +394,19 @@ _inp_rl_addfuncs(void)
     rl_add_funmap_entry("prof_win_8", _inp_rl_win_8_handler);
     rl_add_funmap_entry("prof_win_9", _inp_rl_win_9_handler);
     rl_add_funmap_entry("prof_win_0", _inp_rl_win_0_handler);
+    rl_add_funmap_entry("prof_win_11", _inp_rl_win_11_handler);
+    rl_add_funmap_entry("prof_win_12", _inp_rl_win_12_handler);
+    rl_add_funmap_entry("prof_win_13", _inp_rl_win_13_handler);
+    rl_add_funmap_entry("prof_win_14", _inp_rl_win_14_handler);
+    rl_add_funmap_entry("prof_win_15", _inp_rl_win_15_handler);
+    rl_add_funmap_entry("prof_win_16", _inp_rl_win_16_handler);
+    rl_add_funmap_entry("prof_win_17", _inp_rl_win_17_handler);
+    rl_add_funmap_entry("prof_win_18", _inp_rl_win_18_handler);
+    rl_add_funmap_entry("prof_win_19", _inp_rl_win_19_handler);
+    rl_add_funmap_entry("prof_win_20", _inp_rl_win_20_handler);
     rl_add_funmap_entry("prof_win_prev", _inp_rl_win_prev_handler);
     rl_add_funmap_entry("prof_win_next", _inp_rl_win_next_handler);
+    rl_add_funmap_entry("prof_win_next_unread", _inp_rl_win_next_unread_handler);
     rl_add_funmap_entry("prof_win_pageup", _inp_rl_win_pageup_handler);
     rl_add_funmap_entry("prof_win_pagedown", _inp_rl_win_pagedown_handler);
     rl_add_funmap_entry("prof_subwin_pageup", _inp_rl_subwin_pageup_handler);
@@ -406,6 +430,16 @@ _inp_rl_startup_hook(void)
     rl_bind_keyseq("\\e8", _inp_rl_win_8_handler);
     rl_bind_keyseq("\\e9", _inp_rl_win_9_handler);
     rl_bind_keyseq("\\e0", _inp_rl_win_0_handler);
+    rl_bind_keyseq("\\eq", _inp_rl_win_11_handler);
+    rl_bind_keyseq("\\ew", _inp_rl_win_12_handler);
+    rl_bind_keyseq("\\ee", _inp_rl_win_13_handler);
+    rl_bind_keyseq("\\er", _inp_rl_win_14_handler);
+    rl_bind_keyseq("\\et", _inp_rl_win_15_handler);
+    rl_bind_keyseq("\\ey", _inp_rl_win_16_handler);
+    rl_bind_keyseq("\\eu", _inp_rl_win_17_handler);
+    rl_bind_keyseq("\\ei", _inp_rl_win_18_handler);
+    rl_bind_keyseq("\\eo", _inp_rl_win_19_handler);
+    rl_bind_keyseq("\\ep", _inp_rl_win_20_handler);
 
     rl_bind_keyseq("\\eOP", _inp_rl_win_1_handler);
     rl_bind_keyseq("\\eOQ", _inp_rl_win_2_handler);
@@ -426,6 +460,8 @@ _inp_rl_startup_hook(void)
     rl_bind_keyseq("\\e[1;3C", _inp_rl_win_next_handler);
     rl_bind_keyseq("\\e\\e[C", _inp_rl_win_next_handler);
 
+    rl_bind_keyseq("\\ea", _inp_rl_win_next_unread_handler);
+
     rl_bind_keyseq("\\e\\e[5~", _inp_rl_subwin_pageup_handler);
     rl_bind_keyseq("\\e[5;3~", _inp_rl_subwin_pageup_handler);
     rl_bind_keyseq("\\e\\eOy", _inp_rl_subwin_pageup_handler);
@@ -442,6 +478,8 @@ _inp_rl_startup_hook(void)
     rl_bind_key('\t', _inp_rl_tab_handler);
     rl_bind_keyseq("\\e[Z", _inp_rl_shift_tab_handler);
 
+    rl_bind_keyseq("\\e[1;5B", _inp_rl_down_arrow_handler); // ctrl+arrow down
+
     // unbind unwanted mappings
     rl_bind_keyseq("\\e=", NULL);
 
@@ -649,6 +687,76 @@ _inp_rl_win_0_handler(int count, int key)
     return 0;
 }
 
+static int
+_inp_rl_win_11_handler(int count, int key)
+{
+    _go_to_win(11);
+    return 0;
+}
+
+static int
+_inp_rl_win_12_handler(int count, int key)
+{
+    _go_to_win(12);
+    return 0;
+}
+
+static int
+_inp_rl_win_13_handler(int count, int key)
+{
+    _go_to_win(13);
+    return 0;
+}
+
+static int
+_inp_rl_win_14_handler(int count, int key)
+{
+    _go_to_win(14);
+    return 0;
+}
+
+static int
+_inp_rl_win_15_handler(int count, int key)
+{
+    _go_to_win(15);
+    return 0;
+}
+
+static int
+_inp_rl_win_16_handler(int count, int key)
+{
+    _go_to_win(16);
+    return 0;
+}
+
+static int
+_inp_rl_win_17_handler(int count, int key)
+{
+    _go_to_win(17);
+    return 0;
+}
+
+static int
+_inp_rl_win_18_handler(int count, int key)
+{
+    _go_to_win(18);
+    return 0;
+}
+
+static int
+_inp_rl_win_19_handler(int count, int key)
+{
+    _go_to_win(19);
+    return 0;
+}
+
+static int
+_inp_rl_win_20_handler(int count, int key)
+{
+    _go_to_win(20);
+    return 0;
+}
+
 static int
 _inp_rl_win_prev_handler(int count, int key)
 {
@@ -669,6 +777,16 @@ _inp_rl_win_next_handler(int count, int key)
     return 0;
 }
 
+static int
+_inp_rl_win_next_unread_handler(int count, int key)
+{
+    ProfWin *window = wins_get_next_unread();
+    if (window) {
+        ui_focus_win(window);
+    }
+    return 0;
+}
+
 static int
 _inp_rl_win_pageup_handler(int count, int key)
 {
@@ -700,3 +818,13 @@ _inp_rl_subwin_pagedown_handler(int count, int key)
     win_sub_page_down(current);
     return 0;
 }
+
+static int
+_inp_rl_down_arrow_handler(int count, int key)
+{
+    add_history(rl_line_buffer);
+    using_history();
+    rl_replace_line("", 0);
+    rl_redisplay();
+    return 0;
+}
