@@ -1,8 +1,9 @@
 /*
  * mucwin.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -504,8 +505,6 @@ mucwin_outgoing_msg(ProfMucWin *mucwin, const char *const message, const char *c
 {
     assert(mucwin != NULL);
 
-    g_hash_table_insert(mucwin->sent_messages, strdup(id), NULL);
-
     ProfWin *window = (ProfWin*)mucwin;
     char *mynick = muc_nick(mucwin->roomjid);
 
@@ -529,7 +528,7 @@ mucwin_incoming_msg(ProfMucWin *mucwin, ProfMessage *message, GSList *mentions,
     assert(mucwin != NULL);
     int flags = 0;
 
-    if (message->id && g_hash_table_remove(mucwin->sent_messages, message->id)) {
+    if (message_is_sent_by_us(message, TRUE)) {
         /* Ignore reflection messages */
         return;
     }
@@ -552,6 +551,8 @@ mucwin_incoming_msg(ProfMucWin *mucwin, ProfMessage *message, GSList *mentions,
         ch = prefs_get_omemo_char();
     }
 
+    win_insert_last_read_position_marker((ProfWin*)mucwin, mucwin->roomjid);
+
     if (g_slist_length(mentions) > 0) {
         _mucwin_print_mention(window, message->plain, message->jid->resourcepart, mynick, mentions, &ch, flags);
     } else if (triggers) {
@@ -569,10 +570,6 @@ mucwin_requires_config(ProfMucWin *mucwin)
 
     ProfWin *window = (ProfWin*)mucwin;
     int num = wins_get_num(window);
-    int ui_index = num;
-    if (ui_index == 10) {
-        ui_index = 0;
-    }
 
     win_println(window, THEME_DEFAULT, '-', "");
     win_println(window, THEME_ROOMINFO, '!', "Room locked, requires configuration.");
