@@ -1,8 +1,9 @@
 /*
  * occupantswin.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -43,9 +44,19 @@
 static void
 _occuptantswin_occupant(ProfLayoutSplit *layout, Occupant *occupant, gboolean showjid)
 {
-    const char *presence_str = string_from_resource_presence(occupant->presence);
-    theme_item_t presence_colour = theme_main_presence_attrs(presence_str);
-    wattron(layout->subwin, theme_attrs(presence_colour));
+    int colour;
+    theme_item_t presence_colour = THEME_ROSTER_ONLINE; //init to workaround compiler warning
+
+    if (prefs_get_boolean(PREF_OCCUPANTS_COLOR_NICK)) {
+        colour = theme_hash_attrs(occupant->nick);
+
+        wattron(layout->subwin, colour);
+    } else {
+        const char *presence_str = string_from_resource_presence(occupant->presence);
+        presence_colour = theme_main_presence_attrs(presence_str);
+
+        wattron(layout->subwin, theme_attrs(presence_colour));
+    }
 
     GString *spaces = g_string_new(" ");
 
@@ -85,7 +96,11 @@ _occuptantswin_occupant(ProfLayoutSplit *layout, Occupant *occupant, gboolean sh
 
     g_string_free(spaces, TRUE);
 
-    wattroff(layout->subwin, theme_attrs(presence_colour));
+    if (prefs_get_boolean(PREF_OCCUPANTS_COLOR_NICK)) {
+        wattroff(layout->subwin, colour);
+    } else {
+        wattroff(layout->subwin, theme_attrs(presence_colour));
+    }
 }
 
 void
