@@ -1,7 +1,9 @@
 /*
  * rosterwin.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -67,6 +69,7 @@ static void _rosterwin_rooms(ProfLayoutSplit *layout, char *title, GList *rooms)
 static void _rosterwin_rooms_by_service(ProfLayoutSplit *layout);
 static void _rosterwin_rooms_header(ProfLayoutSplit *layout, GList *rooms, char *title);
 static void _rosterwin_room(ProfLayoutSplit *layout, ProfMucWin *mucwin);
+static void _rosterwin_print_rooms(ProfLayoutSplit *layout);
 
 static void _rosterwin_private_chats(ProfLayoutSplit *layout, GList *orphaned_privchats);
 static void _rosterwin_private_header(ProfLayoutSplit *layout, GList *privs);
@@ -96,15 +99,7 @@ rosterwin_roster(void)
 
     char *roomspos = prefs_get_string(PREF_ROSTER_ROOMS_POS);
     if (prefs_get_boolean(PREF_ROSTER_ROOMS) && (g_strcmp0(roomspos, "first") == 0)) {
-        char *roomsbypref = prefs_get_string(PREF_ROSTER_ROOMS_BY);
-        if (g_strcmp0(roomsbypref, "service") == 0) {
-            _rosterwin_rooms_by_service(layout);
-        } else {
-            GList *rooms = muc_rooms();
-            _rosterwin_rooms(layout, "Rooms", rooms);
-            g_list_free(rooms);
-        }
-        prefs_free_string(roomsbypref);
+        _rosterwin_print_rooms(layout);
 
         GList *orphaned_privchats = NULL;
         GList *privchats = wins_get_private_chats(NULL);
@@ -157,15 +152,7 @@ rosterwin_roster(void)
     }
 
     if (prefs_get_boolean(PREF_ROSTER_ROOMS) && (g_strcmp0(roomspos, "last") == 0)) {
-        char *roomsbypref = prefs_get_string(PREF_ROSTER_ROOMS_BY);
-        if (g_strcmp0(roomsbypref, "service") == 0) {
-            _rosterwin_rooms_by_service(layout);
-        } else {
-            GList *rooms = muc_rooms();
-            _rosterwin_rooms(layout, "Rooms", rooms);
-            g_list_free(rooms);
-        }
-        prefs_free_string(roomsbypref);
+        _rosterwin_print_rooms(layout);
 
         GList *orphaned_privchats = NULL;
         GList *privchats = wins_get_private_chats(NULL);
@@ -366,8 +353,14 @@ _rosterwin_contact(ProfLayoutSplit *layout, PContact contact)
     }
 
     theme_item_t presence_colour = _get_roster_theme(theme_type, presence);
+    int colour;
+    if (prefs_get_boolean(PREF_ROSTER_COLOR_NICK)) {
+        colour = theme_hash_attrs(name);
+        wattron(layout->subwin, colour);
+    } else {
+        wattron(layout->subwin, theme_attrs(presence_colour));
+    }
 
-    wattron(layout->subwin, theme_attrs(presence_colour));
     GString *msg = g_string_new(" ");
     int indent = prefs_get_roster_contact_indent();
     int current_indent = 0;
@@ -403,7 +396,12 @@ _rosterwin_contact(ProfLayoutSplit *layout, PContact contact)
     gboolean wrap = prefs_get_boolean(PREF_ROSTER_WRAP);
     win_sub_print(layout->subwin, msg->str, FALSE, wrap, current_indent);
     g_string_free(msg, TRUE);
-    wattroff(layout->subwin, theme_attrs(presence_colour));
+
+    if (prefs_get_boolean(PREF_ROSTER_COLOR_NICK)) {
+        wattroff(layout->subwin, colour);
+    } else {
+        wattroff(layout->subwin, theme_attrs(presence_colour));
+    }
 
     if (prefs_get_boolean(PREF_ROSTER_RESOURCE)) {
         _rosterwin_resources(layout, contact, current_indent, theme_type, unread);
@@ -411,6 +409,7 @@ _rosterwin_contact(ProfLayoutSplit *layout, PContact contact)
         if (unread > 0) {
             GString *unreadmsg = g_string_new("");
             g_string_append_printf(unreadmsg, " (%d)", unread);
+
             wattron(layout->subwin, theme_attrs(presence_colour));
             win_sub_print(layout->subwin, unreadmsg->str, FALSE, wrap, current_indent);
             g_string_free(unreadmsg, TRUE);
@@ -755,22 +754,44 @@ _rosterwin_room(ProfLayoutSplit *layout, ProfMucWin *mucwin)
     if ((g_strcmp0(unreadpos, "before") == 0) && mucwin->unread > 0) {
         g_string_append_printf(msg, "(%d) ", mucwin->unread);
     }
+
+    char *use_as_name = prefs_get_string(PREF_ROSTER_ROOMS_USE_AS_NAME);
     char *roombypref = prefs_get_string(PREF_ROSTER_ROOMS_BY);
+
     if (g_strcmp0(roombypref, "service") == 0) {
-        Jid *jidp = jid_create(mucwin->roomjid);
-        g_string_append(msg, jidp->localpart);
-        jid_destroy(jidp);
-    } else {
-        gboolean show_server = prefs_get_boolean(PREF_ROSTER_ROOMS_SERVER);
-        if (show_server) {
-            g_string_append(msg, mucwin->roomjid);
-        } else {
+        if (mucwin->room_name == NULL || (g_strcmp0(use_as_name, "jid") == 0)) {
             Jid *jidp = jid_create(mucwin->roomjid);
             g_string_append(msg, jidp->localpart);
+            jid_destroy(jidp);
+        } else {
+            g_string_append(msg, mucwin->room_name);
+        }
+    } else {
+        gboolean show_server = prefs_get_boolean(PREF_ROSTER_ROOMS_SERVER);
+
+        if (show_server) {
+            if (mucwin->room_name == NULL || (g_strcmp0(use_as_name, "jid") == 0)) {
+                g_string_append(msg, mucwin->roomjid);
+            } else {
+                g_string_append(msg, mucwin->room_name);
+            }
+        } else {
+            Jid *jidp = jid_create(mucwin->roomjid);
+
+            if (mucwin->room_name == NULL ||
+                    (g_strcmp0(use_as_name, "jid") == 0)) {
+                g_string_append(msg, jidp->localpart);
+            } else {
+                g_string_append(msg, mucwin->room_name);
+            }
+
             jid_destroy(jidp);
         }
     }
+
+    prefs_free_string(use_as_name);
     prefs_free_string(roombypref);
+
     if ((g_strcmp0(unreadpos, "after") == 0) && mucwin->unread > 0) {
         g_string_append_printf(msg, " (%d)", mucwin->unread);
     }
@@ -866,6 +887,20 @@ _rosterwin_room(ProfLayoutSplit *layout, ProfMucWin *mucwin)
     prefs_free_string(privpref);
 }
 
+static void
+_rosterwin_print_rooms(ProfLayoutSplit *layout)
+{
+    char *roomsbypref = prefs_get_string(PREF_ROSTER_ROOMS_BY);
+    if (g_strcmp0(roomsbypref, "service") == 0) {
+        _rosterwin_rooms_by_service(layout);
+    } else {
+        GList *rooms = muc_rooms();
+        _rosterwin_rooms(layout, "Rooms", rooms);
+        g_list_free(rooms);
+    }
+    prefs_free_string(roomsbypref);
+}
+
 static void
 _rosterwin_private_chats(ProfLayoutSplit *layout, GList *orphaned_privchats)
 {
