@@ -1,8 +1,9 @@
 /*
  * statusbar.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
- * Copyright (C) 2019 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -136,8 +137,8 @@ status_bar_resize(void)
     int cols = getmaxx(stdscr);
     werase(statusbar_win);
     int row = screen_statusbar_row();
-    mvwin(statusbar_win, row, 0);
     wresize(statusbar_win, 1, cols);
+    mvwin(statusbar_win, row, 0);
 
     status_bar_draw();
 }
@@ -198,7 +199,9 @@ _create_tab(const int win, win_type_t wintype, char *identifier, gboolean highli
             char *pref = prefs_get_string(PREF_STATUSBAR_CHAT);
             if (g_strcmp0("user", pref) == 0) {
                 Jid *jidp = jid_create(tab->identifier);
-                tab->display_name = strdup(jidp->localpart);
+                tab->display_name = jidp->localpart != NULL ?
+						strdup(jidp->localpart) :
+						strdup(jidp->barejid);
                 jid_destroy(jidp);
             } else {
                 tab->display_name = strdup(tab->identifier);
@@ -334,9 +337,16 @@ _status_bar_draw_extended_tabs(int pos)
 
         pos = _status_bar_draw_bracket(is_current, pos, "[");
 
-        int status_attrs = theme_attrs(THEME_STATUS_ACTIVE);
-        if (_extended_new()) {
+        int status_attrs;
+        if (is_current) {
+            // currently selected
+            status_attrs = theme_attrs(THEME_STATUS_CURRENT);
+        } else if (_extended_new()) {
+            // new one
             status_attrs = theme_attrs(THEME_STATUS_NEW);
+        } else {
+            // all other
+            status_attrs = theme_attrs(THEME_STATUS_ACTIVE);
         }
         wattron(statusbar_win, status_attrs);
         mvwprintw(statusbar_win, 0, pos, ">");
@@ -360,8 +370,10 @@ _status_bar_draw_tab(StatusBarTab *tab, int pos, int num)
 
     pos = _status_bar_draw_bracket(is_current, pos, "[");
 
-    int status_attrs = 0;
-    if (tab->highlight) {
+    int status_attrs;
+    if (is_current) {
+        status_attrs = theme_attrs(THEME_STATUS_CURRENT);
+    } else if (tab->highlight) {
         status_attrs = theme_attrs(THEME_STATUS_NEW);
     } else {
         status_attrs = theme_attrs(THEME_STATUS_ACTIVE);
