@@ -1,7 +1,9 @@
 /*
  * titlebar.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -107,9 +109,10 @@ title_bar_resize(void)
     werase(win);
 
     int row = screen_titlebar_row();
-    mvwin(win, row, 0);
 
     wresize(win, 1, cols);
+    mvwin(win, row, 0);
+
     wbkgd(win, theme_attrs(THEME_TITLE_TEXT));
 
     _title_bar_draw();
@@ -173,8 +176,6 @@ title_bar_set_typing(gboolean is_typing)
     }
 
     typing = is_typing;
-
-
     _title_bar_draw();
 }
 
@@ -190,7 +191,26 @@ _title_bar_draw(void)
         waddch(win, ' ');
     }
 
-    char *title = win_get_title(current);
+    char *title = NULL;
+    if (current && current->type == WIN_MUC) {
+        char *use_as_name = prefs_get_string(PREF_TITLEBAR_MUC_TITLE);
+
+        if ((g_strcmp0(use_as_name, "name") == 0)) {
+            ProfMucWin *mucwin = (ProfMucWin*) current;
+            assert(mucwin->memcheck == PROFMUCWIN_MEMCHECK);
+
+            if (mucwin->room_name) {
+                title = strdup(mucwin->room_name);
+            }
+        }
+
+        prefs_free_string(use_as_name);
+    }
+
+    if (title == NULL) {
+        title = win_get_title(current);
+    }
+
     mvwprintw(win, 0, 0, " %s", title);
     free(title);
 
