@@ -1,5 +1,6 @@
 /*
  * ui.h
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -289,8 +290,7 @@ void cons_console_setting(void);
 void cons_flash_setting(void);
 void cons_tray_setting(void);
 void cons_splash_setting(void);
-void cons_encwarn_setting(void);
-void cons_tlsshow_setting(void);
+void cons_titlebar_setting(void);
 void cons_vercheck_setting(void);
 void cons_occupants_setting(void);
 void cons_roster_setting(void);
@@ -308,8 +308,7 @@ void cons_history_setting(void);
 void cons_carbons_setting(void);
 void cons_receipts_setting(void);
 void cons_log_setting(void);
-void cons_chlog_setting(void);
-void cons_grlog_setting(void);
+void cons_logging_setting(void);
 void cons_autoaway_setting(void);
 void cons_reconnect_setting(void);
 void cons_autoping_setting(void);
@@ -318,6 +317,8 @@ void cons_room_cache_setting(void);
 void cons_inpblock_setting(void);
 void cons_statusbar_setting(void);
 void cons_winpos_setting(void);
+void cons_color_setting(void);
+void cons_os_setting(void);
 void cons_show_contact_online(PContact contact, Resource *resource, GDateTime *last_activity);
 void cons_show_contact_offline(PContact contact, char *resource, char *status);
 void cons_theme_properties(void);
