@@ -1,5 +1,6 @@
 /*
  * window.h
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -89,4 +90,7 @@ void win_page_down(ProfWin *window);
 void win_sub_page_down(ProfWin *window);
 void win_sub_page_up(ProfWin *window);
 
+void win_insert_last_read_position_marker(ProfWin *window, char* id);
+void win_remove_entry_message(ProfWin *window, const char *const id);
+
 #endif
