@@ -1,7 +1,9 @@
 /*
  * window_list.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
+ * Copyright (C) 2019 - 2020 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -368,20 +370,12 @@ wins_get_by_string(const char *str)
 {
     if (g_strcmp0(str, "console") == 0) {
         ProfWin *conswin = wins_get_console();
-        if (conswin) {
-            return conswin;
-        } else {
-            return NULL;
-        }
+        return conswin;
     }
 
     if (g_strcmp0(str, "xmlconsole") == 0) {
         ProfXMLWin *xmlwin = wins_get_xmlconsole();
-        if (xmlwin) {
             return (ProfWin*)xmlwin;
-        } else {
-            return NULL;
-        }
     }
 
     ProfChatWin *chatwin = wins_get_chat(str);
@@ -561,7 +555,6 @@ wins_close_by_num(int i)
                 ProfMucWin *mucwin = (ProfMucWin*)window;
                 autocomplete_remove(wins_ac, mucwin->roomjid);
                 autocomplete_remove(wins_close_ac, mucwin->roomjid);
-                g_hash_table_remove_all(mucwin->sent_messages);
 
                 if (mucwin->last_msg_timestamp) {
                     g_date_time_unref(mucwin->last_msg_timestamp);
@@ -1100,13 +1093,13 @@ wins_create_summary(gboolean unread)
 }
 
 char*
-win_autocomplete(const char *const search_str, gboolean previous)
+win_autocomplete(const char *const search_str, gboolean previous, void *context)
 {
     return autocomplete_complete(wins_ac, search_str, TRUE, previous);
 }
 
 char*
-win_close_autocomplete(const char *const search_str, gboolean previous)
+win_close_autocomplete(const char *const search_str, gboolean previous, void *context)
 {
     return autocomplete_complete(wins_close_ac, search_str, TRUE, previous);
 }
@@ -1130,3 +1123,29 @@ wins_destroy(void)
     autocomplete_free(wins_ac);
     autocomplete_free(wins_close_ac);
 }
+
+ProfWin*
+wins_get_next_unread(void)
+{
+    // get and sort win nums
+    GList *values = g_hash_table_get_values(windows);
+    values = g_list_sort(values, _wins_cmp_num);
+    GList *curr = values;
+
+    while (curr) {
+        if (current == GPOINTER_TO_INT(curr->data)) {
+            break;
+        }
+
+        ProfWin *window = curr->data;
+        if (win_unread(window) > 0) {
+            g_list_free(values);
+            return window;
+        }
+
+        curr = g_list_next(curr);
+    }
+
+    g_list_free(values);
+    return NULL;
+}
