@@ -1,5 +1,6 @@
 /*
  * connection.h
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -62,6 +63,6 @@ void connection_clear_data(void);
 void connection_add_available_resource(Resource *resource);
 void connection_remove_available_resource(const char *const resource);
 
-char* connection_create_stanza_id(char *prefix);
+char* connection_create_stanza_id(void);
 
 #endif
