@@ -1,5 +1,6 @@
 /*
  * iq.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -92,6 +93,11 @@ typedef struct privilege_set_t {
     char *privilege;
 } ProfPrivilegeSet;
 
+typedef struct affiliation_list_t {
+    char *affiliation;
+    bool show_ui_message;
+} ProfAffiliationList;
+
 typedef struct command_config_data_t {
     char *sessionid;
     char *command;
@@ -134,6 +140,7 @@ static int _command_exec_response_handler(xmpp_stanza_t *const stanza, void *con
 
 static void _iq_free_room_data(ProfRoomInfoData *roominfo);
 static void _iq_free_affiliation_set(ProfPrivilegeSet *affiliation_set);
+static void _iq_free_affiliation_list(ProfAffiliationList *affiliation_list);
 static void _iq_id_handler_free(ProfIqHandler *handler);
 
 // scheduled
@@ -349,7 +356,7 @@ iq_room_list_request(gchar *conferencejid, gchar *filter)
     log_debug("Rooms request not cached for: %s", conferencejid);
 
     xmpp_ctx_t * const ctx = connection_get_ctx();
-    char *id = connection_create_stanza_id("confreq");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = stanza_create_disco_items_iq(ctx, id, conferencejid, NULL);
 
     iq_id_handler_add(id, _room_list_id_handler, NULL, filter);
@@ -394,9 +401,8 @@ iq_http_upload_request(HTTPUpload *upload)
     }
 
     xmpp_ctx_t * const ctx = connection_get_ctx();
-    char *id = connection_create_stanza_id("http_upload_request");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = stanza_create_http_upload_request(ctx, id, jid, upload);
-    // TODO add free func
     iq_id_handler_add(id, _http_upload_response_id_handler, NULL, upload);
     free(id);
 
@@ -410,7 +416,7 @@ void
 iq_disco_info_request(gchar *jid)
 {
     xmpp_ctx_t * const ctx = connection_get_ctx();
-    char *id = connection_create_stanza_id("disco_info");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = stanza_create_disco_info_iq(ctx, id, jid, NULL);
 
     iq_id_handler_add(id, _disco_info_response_id_handler, NULL, NULL);
@@ -425,7 +431,7 @@ void
 iq_disco_info_request_onconnect(gchar *jid)
 {
     xmpp_ctx_t * const ctx = connection_get_ctx();
-    char *id = connection_create_stanza_id("disco_info_onconnect");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = stanza_create_disco_info_iq(ctx, id, jid, NULL);
 
     iq_id_handler_add(id, _disco_info_response_id_handler_onconnect, NULL, NULL);
@@ -440,7 +446,7 @@ void
 iq_last_activity_request(gchar *jid)
 {
     xmpp_ctx_t * const ctx = connection_get_ctx();
-    char *id = connection_create_stanza_id("lastactivity");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = stanza_create_last_activity_iq(ctx, id, jid);
 
     iq_id_handler_add(id, _last_activity_response_id_handler, NULL, NULL);
@@ -455,7 +461,7 @@ void
 iq_room_info_request(const char *const room, gboolean display_result)
 {
     xmpp_ctx_t * const ctx = connection_get_ctx();
-    char *id = connection_create_stanza_id("room_disco_info");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = stanza_create_disco_info_iq(ctx, id, room, NULL);
 
     ProfRoomInfoData *cb_data = malloc(sizeof(ProfRoomInfoData));
@@ -637,13 +643,18 @@ iq_room_config_cancel(ProfConfWin *confwin)
 }
 
 void
-iq_room_affiliation_list(const char *const room, char *affiliation)
+iq_room_affiliation_list(const char *const room, char *affiliation, bool show_ui_message)
 {
     xmpp_ctx_t * const ctx = connection_get_ctx();
     xmpp_stanza_t *iq = stanza_create_room_affiliation_list_iq(ctx, room, affiliation);
 
     const char *id = xmpp_stanza_get_id(iq);
-    iq_id_handler_add(id, _room_affiliation_list_result_id_handler, free, strdup(affiliation));
+
+    ProfAffiliationList *affiliation_list = malloc(sizeof(ProfAffiliationList));
+    affiliation_list->affiliation = strdup(affiliation);
+    affiliation_list->show_ui_message = show_ui_message;
+
+    iq_id_handler_add(id, _room_affiliation_list_result_id_handler, (ProfIqFreeCallback)_iq_free_affiliation_list, affiliation_list);
 
     iq_send_stanza(iq);
     xmpp_stanza_release(iq);
@@ -731,7 +742,7 @@ void
 iq_command_list(const char *const target)
 {
     xmpp_ctx_t * const ctx = connection_get_ctx();
-    const char *id = connection_create_stanza_id("cmdlist");
+    const char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = stanza_create_disco_items_iq(ctx, id, target, STANZA_NS_COMMAND);
 
     iq_id_handler_add(id, _command_list_result_handler, NULL, NULL);
@@ -1553,6 +1564,10 @@ _version_get_handler(xmpp_stanza_t *const stanza)
     }
 
     if (from) {
+        if (prefs_get_boolean(PREF_ADV_NOTIFY_DISCO_OR_VERSION)) {
+            cons_show("Received IQ version request (XEP-0092) from %s", from);
+        }
+
         xmpp_stanza_t *response = xmpp_iq_new(ctx, STANZA_TYPE_RESULT, id);
         xmpp_stanza_set_to(response, from);
 
@@ -1583,8 +1598,37 @@ _version_get_handler(xmpp_stanza_t *const stanza)
         xmpp_stanza_set_text(version_txt, version_str->str);
         xmpp_stanza_add_child(version, version_txt);
 
+        xmpp_stanza_t *os;
+        xmpp_stanza_t *os_txt;
+
+        bool include_os = prefs_get_boolean(PREF_REVEAL_OS);
+        if (include_os) {
+            os = xmpp_stanza_new(ctx);
+            xmpp_stanza_set_name(os, "os");
+
+            os_txt = xmpp_stanza_new(ctx);
+
+#if defined(_WIN32) || defined(__CYGWIN__) || defined(PLATFORM_CYGWIN)
+            xmpp_stanza_set_text(os_txt, "Windows");
+#elif defined(__linux__)
+            xmpp_stanza_set_text(os_txt, "Linux");
+#elif defined(__APPLE__)
+            xmpp_stanza_set_text(os_txt, "Apple");
+#elif defined(__FreeBSD__)
+            xmpp_stanza_set_text(os_txt, "FreeBSD");
+#elif defined(__NetBSD__)
+            xmpp_stanza_set_text(os_txt, "__NetBSD__");
+#elif defined(__OpenBSD__)
+            xmpp_stanza_set_text(os_txt, "__OpenBSD__");
+#else
+            xmpp_stanza_set_text(os_txt, "Unknown");
+#endif
+            xmpp_stanza_add_child(os, os_txt);
+        }
+
         xmpp_stanza_add_child(query, name);
         xmpp_stanza_add_child(query, version);
+        if (include_os) {xmpp_stanza_add_child(query, os);}
         xmpp_stanza_add_child(response, query);
 
         iq_send_stanza(response);
@@ -1592,8 +1636,10 @@ _version_get_handler(xmpp_stanza_t *const stanza)
         g_string_free(version_str, TRUE);
         xmpp_stanza_release(name_txt);
         xmpp_stanza_release(version_txt);
+        if (include_os) {xmpp_stanza_release(os_txt);}
         xmpp_stanza_release(name);
         xmpp_stanza_release(version);
+        if (include_os) {xmpp_stanza_release(os);}
         xmpp_stanza_release(query);
         xmpp_stanza_release(response);
     }
@@ -1698,6 +1744,10 @@ _disco_info_get_handler(xmpp_stanza_t *const stanza)
     }
 
     if (from) {
+        if (prefs_get_boolean(PREF_ADV_NOTIFY_DISCO_OR_VERSION)) {
+            cons_show("Received IQ disco info request (XEP-0232) from %s", from);
+        }
+
         xmpp_stanza_t *response = xmpp_iq_new(ctx, STANZA_TYPE_RESULT, xmpp_stanza_get_id(stanza));
         xmpp_stanza_set_to(response, from);
 
@@ -1851,7 +1901,7 @@ _room_affiliation_list_result_id_handler(xmpp_stanza_t *const stanza, void *cons
     const char *id = xmpp_stanza_get_id(stanza);
     const char *type = xmpp_stanza_get_type(stanza);
     const char *from = xmpp_stanza_get_from(stanza);
-    char *affiliation = (char *)userdata;
+    ProfAffiliationList *affiliation_list = (ProfAffiliationList *)userdata;
 
     if (id) {
         log_debug("IQ affiliation list result handler fired, id: %s.", id);
@@ -1862,10 +1912,10 @@ _room_affiliation_list_result_id_handler(xmpp_stanza_t *const stanza, void *cons
     // handle error responses
     if (g_strcmp0(type, STANZA_TYPE_ERROR) == 0) {
         char *error_message = stanza_get_error_message(stanza);
-        log_debug("Error retrieving %s list for room %s: %s", affiliation, from, error_message);
+        log_debug("Error retrieving %s list for room %s: %s", affiliation_list->affiliation, from, error_message);
         ProfMucWin *mucwin = wins_get_muc(from);
-        if (mucwin) {
-            mucwin_affiliation_list_error(mucwin, affiliation, error_message);
+        if (mucwin && affiliation_list->show_ui_message) {
+            mucwin_affiliation_list_error(mucwin, affiliation_list->affiliation, error_message);
         }
         free(error_message);
         return 0;
@@ -1880,6 +1930,11 @@ _room_affiliation_list_result_id_handler(xmpp_stanza_t *const stanza, void *cons
             if (g_strcmp0(name, "item") == 0) {
                 const char *jid = xmpp_stanza_get_attribute(child, STANZA_ATTR_JID);
                 if (jid) {
+                    if (g_strcmp0(affiliation_list->affiliation, "member") == 0
+                            || g_strcmp0(affiliation_list->affiliation, "owner") == 0
+                            || g_strcmp0(affiliation_list->affiliation, "admin") == 0) {
+                        muc_members_add(from, jid);
+                    }
                     jids = g_slist_insert_sorted(jids, (gpointer)jid, (GCompareFunc)g_strcmp0);
                 }
             }
@@ -1889,8 +1944,8 @@ _room_affiliation_list_result_id_handler(xmpp_stanza_t *const stanza, void *cons
 
     muc_jid_autocomplete_add_all(from, jids);
     ProfMucWin *mucwin = wins_get_muc(from);
-    if (mucwin) {
-        mucwin_handle_affiliation_list(mucwin, affiliation, jids);
+    if (mucwin && affiliation_list->show_ui_message) {
+        mucwin_handle_affiliation_list(mucwin, affiliation_list->affiliation, jids);
     }
     g_slist_free(jids);
 
@@ -2061,6 +2116,10 @@ _room_info_response_id_handler(xmpp_stanza_t *const stanza, void *const userdata
 
                     if (name) {
                         identity->name = strdup(name);
+                        ProfMucWin *mucwin = wins_get_muc(cb_data->room);
+                        if (mucwin) {
+                            mucwin->room_name = strdup(name);
+                        }
                     } else {
                         identity->name = NULL;
                     }
@@ -2429,3 +2488,12 @@ _iq_free_affiliation_set(ProfPrivilegeSet *affiliation_set)
         free(affiliation_set);
     }
 }
+
+static void
+_iq_free_affiliation_list(ProfAffiliationList *affiliation_list)
+{
+    if (affiliation_list) {
+        free(affiliation_list->affiliation);
+        free(affiliation_list);
+    }
+}
