@@ -1,5 +1,6 @@
 /*
  * jid.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -198,18 +199,10 @@ jid_fulljid_or_barejid(Jid *jid)
 char*
 jid_random_resource(void)
 {
-    GRand *prng;
-    char rand[5];
-    char alphabet[] = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
+    char *rand = get_random_string(4);
 
-    prng = g_rand_new();
+    gchar *result = g_strdup_printf("profanity.%s", rand);
+    free(rand);
 
-    int i;
-    for (i = 0; i < 4; i++) {
-        rand[i] = alphabet[g_rand_int_range(prng, 0, sizeof(alphabet))];
-    }
-    rand[4] = '\0';
-    g_rand_free(prng);
-
-    return g_strdup_printf("profanity.%s", rand);
+    return result;
 }
