@@ -1,5 +1,6 @@
 /*
  * message.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -79,7 +80,7 @@ static void _private_chat_handler(xmpp_stanza_t *const stanza);
 
 static void _handle_error(xmpp_stanza_t *const stanza);
 static void _handle_groupchat(xmpp_stanza_t *const stanza);
-static void _handel_muc_user(xmpp_stanza_t *const stanza);
+static void _handle_muc_user(xmpp_stanza_t *const stanza);
 static void _handle_conference(xmpp_stanza_t *const stanza);
 static void _handle_captcha(xmpp_stanza_t *const stanza);
 static void _handle_receipt_received(xmpp_stanza_t *const stanza);
@@ -115,7 +116,7 @@ _message_handler(xmpp_conn_t *const conn, xmpp_stanza_t *const stanza, void *con
 
     xmpp_stanza_t *mucuser = xmpp_stanza_get_child_by_ns(stanza, STANZA_NS_MUC_USER);
     if (mucuser) {
-        _handel_muc_user(stanza);
+        _handle_muc_user(stanza);
     }
 
     xmpp_stanza_t *conference = xmpp_stanza_get_child_by_ns(stanza, STANZA_NS_CONFERENCE);
@@ -186,12 +187,14 @@ message_init(void)
 
     message->jid = NULL;
     message->id = NULL;
+    message->originid = NULL;
     message->body = NULL;
     message->encrypted = NULL;
     message->plain = NULL;
     message->enc = PROF_MSG_ENC_PLAIN;
     message->timestamp = NULL;
     message->trusted = true;
+    message->mucuser = false;
 
     return message;
 }
@@ -208,6 +211,10 @@ message_free(ProfMessage *message)
         xmpp_free(ctx, message->id);
     }
 
+    if (message->originid) {
+        xmpp_free(ctx, message->originid);
+    }
+
     if (message->body) {
         xmpp_free(ctx, message->body);
     }
@@ -254,7 +261,7 @@ message_send_chat(const char *const barejid, const char *const msg, const char *
 
     char *state = chat_session_get_state(barejid);
     char *jid = chat_session_get_jid(barejid);
-    char *id = connection_create_stanza_id("msg");
+    char *id = connection_create_stanza_id();
 
     xmpp_stanza_t *message = xmpp_message_new(ctx, STANZA_TYPE_CHAT, jid, id);
     xmpp_message_set_body(message, msg);
@@ -285,7 +292,7 @@ message_send_chat_pgp(const char *const barejid, const char *const msg, gboolean
 
     char *state = chat_session_get_state(barejid);
     char *jid = chat_session_get_jid(barejid);
-    char *id = connection_create_stanza_id("msg");
+    char *id = connection_create_stanza_id();
 
     xmpp_stanza_t *message = NULL;
 #ifdef HAVE_LIBGPGME
@@ -344,7 +351,7 @@ message_send_chat_otr(const char *const barejid, const char *const msg, gboolean
 
     char *state = chat_session_get_state(barejid);
     char *jid = chat_session_get_jid(barejid);
-    char *id = connection_create_stanza_id("msg");
+    char *id = connection_create_stanza_id();
 
     xmpp_stanza_t *message = xmpp_message_new(ctx, STANZA_TYPE_CHAT, barejid, id);
     xmpp_message_set_body(message, msg);
@@ -381,11 +388,11 @@ message_send_chat_omemo(const char *const jid, uint32_t sid, GList *keys,
     char *id;
     xmpp_stanza_t *message;
     if (muc) {
-        id = connection_create_stanza_id("muc");
+        id = connection_create_stanza_id();
         message = xmpp_message_new(ctx, STANZA_TYPE_GROUPCHAT, jid, id);
         stanza_attach_origin_id(ctx, message, id);
     } else {
-        id = connection_create_stanza_id("msg");
+        id = connection_create_stanza_id();
         message = xmpp_message_new(ctx, STANZA_TYPE_CHAT, jid, id);
     }
 
@@ -485,7 +492,7 @@ void
 message_send_private(const char *const fulljid, const char *const msg, const char *const oob_url)
 {
     xmpp_ctx_t * const ctx = connection_get_ctx();
-    char *id = connection_create_stanza_id("prv");
+    char *id = connection_create_stanza_id();
 
     xmpp_stanza_t *message = xmpp_message_new(ctx, STANZA_TYPE_CHAT, fulljid, id);
     xmpp_message_set_body(message, msg);
@@ -504,7 +511,7 @@ char*
 message_send_groupchat(const char *const roomjid, const char *const msg, const char *const oob_url)
 {
     xmpp_ctx_t * const ctx = connection_get_ctx();
-    char *id = connection_create_stanza_id("muc");
+    char *id = connection_create_stanza_id();
 
     xmpp_stanza_t *message = xmpp_message_new(ctx, STANZA_TYPE_GROUPCHAT, roomjid, id);
     stanza_attach_origin_id(ctx, message, id);
@@ -639,7 +646,7 @@ _handle_error(xmpp_stanza_t *const stanza)
 }
 
 static void
-_handel_muc_user(xmpp_stanza_t *const stanza)
+_handle_muc_user(xmpp_stanza_t *const stanza)
 {
     xmpp_ctx_t *ctx = connection_get_ctx();
     xmpp_stanza_t *xns_muc_user = xmpp_stanza_get_child_by_ns(stanza, STANZA_NS_MUC_USER);
@@ -747,10 +754,11 @@ _handle_groupchat(xmpp_stanza_t *const stanza)
     xmpp_ctx_t *ctx = connection_get_ctx();
 
     const char *id = xmpp_stanza_get_id(stanza);
+    char *originid = NULL;
 
-    xmpp_stanza_t *origin = xmpp_stanza_get_child_by_ns(stanza, STANZA_NS_STABLE_ID);
-    if (origin && g_strcmp0(xmpp_stanza_get_name(origin), STANZA_NAME_ORIGIN_ID) == 0) {
-        id = xmpp_stanza_get_attribute(origin, STANZA_ATTR_ID);
+    xmpp_stanza_t *origin = stanza_get_child_by_name_and_ns(stanza, STANZA_NAME_ORIGIN_ID, STANZA_NS_STABLE_ID);
+    if (origin) {
+        originid = (char*)xmpp_stanza_get_attribute(origin, STANZA_ATTR_ID);
     }
 
     const char *room_jid = xmpp_stanza_get_from(stanza);
@@ -802,6 +810,9 @@ _handle_groupchat(xmpp_stanza_t *const stanza)
     if (id) {
         message->id = strdup(id);
     }
+    if (originid) {
+        message->originid = strdup(originid);
+    }
 
     message->body = xmpp_message_get_body(stanza);
 
@@ -820,9 +831,19 @@ _handle_groupchat(xmpp_stanza_t *const stanza)
         message->plain = strdup(message->body);
     }
 
-    // determine if the notifications happened whilst offline
-    message->timestamp = stanza_get_delay(stanza);
-    if (message->timestamp) {
+    // determine if the notifications happened whilst offline (MUC history)
+    message->timestamp = stanza_get_delay_from(stanza, jid->barejid);
+    if (message->timestamp == NULL) {
+        // checking the domainpart is a workaround for some prosody versions (gh#1190)
+        message->timestamp = stanza_get_delay_from(stanza, jid->domainpart);
+    }
+
+    bool is_muc_history = message->timestamp != NULL;
+
+    // we want to display the oldest delay
+    message->timestamp = stanza_get_oldest_delay(stanza);
+
+    if (is_muc_history) {
         sv_ev_room_history(message);
     } else {
         sv_ev_room_message(message);
@@ -837,7 +858,7 @@ _message_send_receipt(const char *const fulljid, const char *const message_id)
 {
     xmpp_ctx_t * const ctx = connection_get_ctx();
 
-    char *id = connection_create_stanza_id("receipt");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *message = xmpp_message_new(ctx, NULL, fulljid, id);
     free(id);
 
@@ -910,6 +931,7 @@ _private_chat_handler(xmpp_stanza_t *const stanza)
 {
     // standard chat message, use jid without resource
     ProfMessage *message = message_init();
+    message->mucuser = TRUE;
 
     const gchar *from = xmpp_stanza_get_from(stanza);
     message->jid = jid_create(from);
@@ -987,6 +1009,12 @@ _handle_carbons(xmpp_stanza_t *const stanza)
 
     ProfMessage *message = message_init();
 
+    // check whether message was a MUC PM
+    xmpp_stanza_t *mucuser = xmpp_stanza_get_child_by_ns(message_stanza, STANZA_NS_MUC_USER);
+    if (mucuser) {
+        message->mucuser = TRUE;
+    }
+
     // check omemo encryption
 #ifdef HAVE_OMEMO
     message->plain = omemo_receive_message(message_stanza, &message->trusted);
@@ -1006,6 +1034,13 @@ _handle_carbons(xmpp_stanza_t *const stanza)
     Jid *jid_from = jid_create(from);
     Jid *jid_to = jid_create(to);
 
+    if (!message->plain && !message->body) {
+        log_error("Message received without body from: %s", jid_from->fulljid);
+        goto out;
+    } else if (!message->plain) {
+        message->plain = strdup(message->body);
+    }
+
     // check for pgp encrypted message
     xmpp_stanza_t *x = xmpp_stanza_get_child_by_ns(message_stanza, STANZA_NS_ENCRYPTED);
     if (x) {
@@ -1027,9 +1062,9 @@ _handle_carbons(xmpp_stanza_t *const stanza)
         }
     }
 
+out:
     message_free(message);
     jid_destroy(my_jid);
-
     return TRUE;
 }
 
@@ -1078,6 +1113,10 @@ _handle_chat(xmpp_stanza_t *const stanza)
     ProfMessage *message = message_init();
     message->jid = jid;
 
+    if (mucuser) {
+        message->mucuser = TRUE;
+    }
+
     message->timestamp = stanza_get_delay(stanza);
     if (body) {
         message->body = xmpp_stanza_get_text(body);
@@ -1143,3 +1182,48 @@ _send_message_stanza(xmpp_stanza_t *const stanza)
     }
     xmpp_free(connection_get_ctx(), text);
 }
+
+/* ckeckOID = true: check origin-id
+ * checkOID = false: check regular id
+ */
+bool
+message_is_sent_by_us(ProfMessage *message, bool checkOID) {
+    bool ret = FALSE;
+
+    // we check the </origin-id> for this we calculate a hash into it so we can detect
+    // whether this client sent it. See connection_create_stanza_id()
+    if (message) {
+        char *tmp_id = NULL;
+
+        if (checkOID && message->originid != NULL) {
+            tmp_id = message->originid;
+        } else if (!checkOID && message->id != NULL) {
+            tmp_id = message->id;
+        }
+
+        if (tmp_id != NULL) {
+            gsize tmp_len;
+            char *tmp = (char*)g_base64_decode(tmp_id, &tmp_len);
+
+            // our client sents at least 36 (uuid) + identifier
+            if (tmp_len > 36) {
+                char *uuid = g_strndup(tmp, 36);
+                const char *prof_identifier = connection_get_profanity_identifier();
+
+                gchar *hmac = g_compute_hmac_for_string(G_CHECKSUM_SHA256,
+                        (guchar*)prof_identifier, strlen(prof_identifier),
+                        uuid, strlen(uuid));
+
+                if (g_strcmp0(&tmp[36], hmac) == 0) {
+                    ret = TRUE;
+                }
+
+                g_free(uuid);
+                g_free(hmac);
+            }
+            free(tmp);
+        }
+    }
+
+    return  ret;
+}
