@@ -1,5 +1,6 @@
 /*
  * muc.h
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -125,7 +126,7 @@ char* muc_roster_nick_change_complete(const char *const room, const char *const
 
 void muc_confserver_add(const char *const server);
 void muc_confserver_reset_ac(void);
-char* muc_confserver_find(const char *const search_str, gboolean previous);
+char* muc_confserver_find(const char *const search_str, gboolean previous, void *context);
 void muc_confserver_clear(void);
 
 void muc_invites_add(const char *const room, const char *const password);
@@ -134,7 +135,7 @@ gint muc_invites_count(void);
 GList* muc_invites(void);
 gboolean muc_invites_contain(const char *const room);
 void muc_invites_reset_ac(void);
-char* muc_invites_find(const char *const search_str, gboolean previous);
+char* muc_invites_find(const char *const search_str, gboolean previous, void *context);
 void muc_invites_clear(void);
 char* muc_invite_password(const char *const room);
 
@@ -158,4 +159,9 @@ char* muc_affiliation_str(const char *const room);
 muc_member_type_t muc_member_type(const char *const room);
 muc_anonymity_type_t muc_anonymity_type(const char *const room);
 
+GList* muc_members(const char *const room);
+void muc_members_add(const char *const room, const char *const jid);
+void muc_members_remove(const char *const room, const char *const jid);
+void muc_members_update(const char *const room, const char *const jid, const char *const affiliation);
+
 #endif
