@@ -1,5 +1,6 @@
 /*
  * presence.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -128,7 +129,7 @@ presence_subscription(const char *const jid, const jabber_subscr_t action)
     xmpp_ctx_t * const ctx = connection_get_ctx();
     xmpp_stanza_t *presence = xmpp_presence_new(ctx);
 
-    char *id = connection_create_stanza_id("sub");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_set_id(presence, id);
     free(id);
 
@@ -160,7 +161,7 @@ presence_clear_sub_requests(void)
 }
 
 char*
-presence_sub_request_find(const char *const search_str, gboolean previous)
+presence_sub_request_find(const char *const search_str, gboolean previous, void *context)
 {
     return autocomplete_complete(sub_requests_ac, search_str, TRUE, previous);
 }
@@ -211,7 +212,7 @@ presence_send(const resource_presence_t presence_type, const int idle, char *sig
     xmpp_ctx_t * const ctx = connection_get_ctx();
     xmpp_stanza_t *presence = xmpp_presence_new(ctx);
 
-    char *id = connection_create_stanza_id("presence");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_set_id(presence, id);
     free(id);
 
@@ -579,7 +580,7 @@ _handle_caps(const char *const jid, XMPPCaps *caps)
                 caps_map_jid_to_ver(jid, caps->ver);
             } else {
                 log_info("Capabilities cache miss: %s, for %s, sending service discovery request", caps->ver, jid);
-                char *id = connection_create_stanza_id("caps");
+                char *id = connection_create_stanza_id();
                 iq_send_caps_request(jid, id, caps->node, caps->ver);
                 free(id);
             }
@@ -588,14 +589,14 @@ _handle_caps(const char *const jid, XMPPCaps *caps)
     // unsupported hash, xep-0115, associate with JID, no cache
     } else if (caps->hash) {
         log_info("Hash %s not supported: %s, sending service discovery request", caps->hash, jid);
-        char *id = connection_create_stanza_id("caps");
+        char *id = connection_create_stanza_id();
         iq_send_caps_request_for_jid(jid, id, caps->node, caps->ver);
         free(id);
 
    // no hash, legacy caps, cache against node#ver
    } else if (caps->node && caps->ver) {
         log_info("No hash specified: %s, legacy request made for %s#%s", jid, caps->node, caps->ver);
-        char *id = connection_create_stanza_id("caps");
+        char *id = connection_create_stanza_id();
         iq_send_caps_request_legacy(jid, id, caps->node, caps->ver);
         free(id);
     } else {
