@@ -1,5 +1,6 @@
 /*
  * roster_list.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -303,15 +304,7 @@ roster_update(const char *const barejid, const char *const name, GSList *groups,
     p_contact_set_subscription(contact, subscription);
     p_contact_set_pending_out(contact, pending_out);
 
-    const char * const new_name = name;
-    char * current_name = NULL;
-    if (p_contact_name(contact)) {
-        current_name = strdup(p_contact_name(contact));
-    }
-
-    p_contact_set_name(contact, new_name);
-    _replace_name(current_name, new_name, barejid);
-    free(current_name);
+    roster_change_name(contact, name);
 
     GSList *curr_new_group = groups;
     while (curr_new_group) {
@@ -494,7 +487,7 @@ roster_has_pending_subscriptions(void)
 }
 
 char*
-roster_contact_autocomplete(const char *const search_str, gboolean previous)
+roster_contact_autocomplete(const char *const search_str, gboolean previous, void *context)
 {
     assert(roster != NULL);
 
@@ -502,7 +495,7 @@ roster_contact_autocomplete(const char *const search_str, gboolean previous)
 }
 
 char*
-roster_fulljid_autocomplete(const char *const search_str, gboolean previous)
+roster_fulljid_autocomplete(const char *const search_str, gboolean previous, void *context)
 {
     assert(roster != NULL);
 
@@ -557,7 +550,7 @@ roster_get_groups(void)
 }
 
 char*
-roster_group_autocomplete(const char *const search_str, gboolean previous)
+roster_group_autocomplete(const char *const search_str, gboolean previous, void *context)
 {
     assert(roster != NULL);
 
@@ -565,7 +558,7 @@ roster_group_autocomplete(const char *const search_str, gboolean previous)
 }
 
 char*
-roster_barejid_autocomplete(const char *const search_str, gboolean previous)
+roster_barejid_autocomplete(const char *const search_str, gboolean previous, void *context)
 {
     assert(roster != NULL);
 
