@@ -1,5 +1,6 @@
 /*
  * stanza.c
+ * vim: expandtab:ts=4:sts=4:sw=4
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
@@ -66,7 +67,7 @@
 #include "xmpp/form.h"
 #include "xmpp/muc.h"
 
-static void _stanza_add_unique_id(xmpp_stanza_t *stanza, char *prefix);
+static void _stanza_add_unique_id(xmpp_stanza_t *stanza);
 static char* _stanza_create_sha1_hash(char *str);
 
 #if 0
@@ -134,7 +135,7 @@ xmpp_stanza_t*
 stanza_create_bookmarks_pubsub_add(xmpp_ctx_t *ctx, const char *const jid,
     const gboolean autojoin, const char *const nick)
 {
-    char *id = connection_create_stanza_id("bookmark_add");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *stanza = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
 
@@ -280,7 +281,7 @@ stanza_create_http_upload_request(xmpp_ctx_t *ctx, const char *const id,
 xmpp_stanza_t*
 stanza_enable_carbons(xmpp_ctx_t *ctx)
 {
-    char *id = connection_create_stanza_id("carbons");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
 
@@ -297,7 +298,7 @@ stanza_enable_carbons(xmpp_ctx_t *ctx)
 xmpp_stanza_t*
 stanza_disable_carbons(xmpp_ctx_t *ctx)
 {
-    char *id = connection_create_stanza_id("carbons");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
 
@@ -314,7 +315,7 @@ stanza_disable_carbons(xmpp_ctx_t *ctx)
 xmpp_stanza_t*
 stanza_create_chat_state(xmpp_ctx_t *ctx, const char *const fulljid, const char *const state)
 {
-    char *id = connection_create_stanza_id(NULL);
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *msg = xmpp_message_new(ctx, STANZA_TYPE_CHAT, fulljid, id);
     free(id);
 
@@ -446,7 +447,7 @@ stanza_attach_x_oob_url(xmpp_ctx_t *ctx, xmpp_stanza_t *stanza, const char *cons
 xmpp_stanza_t*
 stanza_create_roster_remove_set(xmpp_ctx_t *ctx, const char *const barejid)
 {
-    char *id = connection_create_stanza_id("roster");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
 
@@ -512,7 +513,7 @@ xmpp_stanza_t*
 stanza_create_invite(xmpp_ctx_t *ctx, const char *const room,
     const char *const contact, const char *const reason, const char *const password)
 {
-    char *id = connection_create_stanza_id(NULL);
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *message = xmpp_message_new(ctx, NULL, contact, id);
     free(id);
 
@@ -538,7 +539,7 @@ xmpp_stanza_t*
 stanza_create_mediated_invite(xmpp_ctx_t *ctx, const char *const room,
     const char *const contact, const char *const reason)
 {
-    char *id = connection_create_stanza_id(NULL);
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *message = xmpp_message_new(ctx, NULL, room, id);
     free(id);
 
@@ -575,7 +576,7 @@ stanza_create_room_join_presence(xmpp_ctx_t *const ctx,
 {
     xmpp_stanza_t *presence = xmpp_presence_new(ctx);
     xmpp_stanza_set_to(presence, full_room_jid);
-    _stanza_add_unique_id(presence, "join");
+    _stanza_add_unique_id(presence);
 
     xmpp_stanza_t *x = xmpp_stanza_new(ctx);
     xmpp_stanza_set_name(x, STANZA_NAME_X);
@@ -603,7 +604,7 @@ stanza_create_room_newnick_presence(xmpp_ctx_t *ctx,
     const char *const full_room_jid)
 {
     xmpp_stanza_t *presence = xmpp_presence_new(ctx);
-    _stanza_add_unique_id(presence, "sub");
+    _stanza_add_unique_id(presence);
     xmpp_stanza_set_to(presence, full_room_jid);
 
     return presence;
@@ -620,7 +621,7 @@ stanza_create_room_leave_presence(xmpp_ctx_t *ctx, const char *const room,
     xmpp_stanza_t *presence = xmpp_presence_new(ctx);
     xmpp_stanza_set_type(presence, STANZA_TYPE_UNAVAILABLE);
     xmpp_stanza_set_to(presence, full_jid->str);
-    _stanza_add_unique_id(presence, "leave");
+    _stanza_add_unique_id(presence);
 
     g_string_free(full_jid, TRUE);
 
@@ -630,7 +631,7 @@ stanza_create_room_leave_presence(xmpp_ctx_t *ctx, const char *const room,
 xmpp_stanza_t*
 stanza_create_instant_room_request_iq(xmpp_ctx_t *ctx, const char *const room_jid)
 {
-    char *id = connection_create_stanza_id("room");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
     xmpp_stanza_set_to(iq, room_jid);
@@ -656,7 +657,7 @@ stanza_create_instant_room_request_iq(xmpp_ctx_t *ctx, const char *const room_ji
 xmpp_stanza_t*
 stanza_create_instant_room_destroy_iq(xmpp_ctx_t *ctx, const char *const room_jid)
 {
-    char *id = connection_create_stanza_id("room");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
     xmpp_stanza_set_to(iq, room_jid);
@@ -680,7 +681,7 @@ stanza_create_instant_room_destroy_iq(xmpp_ctx_t *ctx, const char *const room_ji
 xmpp_stanza_t*
 stanza_create_room_config_request_iq(xmpp_ctx_t *ctx, const char *const room_jid)
 {
-    char *id = connection_create_stanza_id("room");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_GET, id);
     free(id);
     xmpp_stanza_set_to(iq, room_jid);
@@ -698,7 +699,7 @@ stanza_create_room_config_request_iq(xmpp_ctx_t *ctx, const char *const room_jid
 xmpp_stanza_t*
 stanza_create_room_config_cancel_iq(xmpp_ctx_t *ctx, const char *const room_jid)
 {
-    char *id = connection_create_stanza_id("room");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
     xmpp_stanza_set_to(iq, room_jid);
@@ -724,7 +725,7 @@ stanza_create_room_config_cancel_iq(xmpp_ctx_t *ctx, const char *const room_jid)
 xmpp_stanza_t*
 stanza_create_room_affiliation_list_iq(xmpp_ctx_t *ctx, const char *const room, const char *const affiliation)
 {
-    char *id = connection_create_stanza_id("affiliation_get");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_GET, id);
     free(id);
     xmpp_stanza_set_to(iq, room);
@@ -748,7 +749,7 @@ stanza_create_room_affiliation_list_iq(xmpp_ctx_t *ctx, const char *const room,
 xmpp_stanza_t*
 stanza_create_room_role_list_iq(xmpp_ctx_t *ctx, const char *const room, const char *const role)
 {
-    char *id = connection_create_stanza_id("role_get");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_GET, id);
     free(id);
     xmpp_stanza_set_to(iq, room);
@@ -773,7 +774,7 @@ xmpp_stanza_t*
 stanza_create_room_affiliation_set_iq(xmpp_ctx_t *ctx, const char *const room, const char *const jid,
     const char *const affiliation, const char *const reason)
 {
-    char *id = connection_create_stanza_id("affiliation_set");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
     xmpp_stanza_set_to(iq, room);
@@ -811,7 +812,7 @@ xmpp_stanza_t*
 stanza_create_room_role_set_iq(xmpp_ctx_t *const ctx, const char *const room, const char *const nick,
     const char *const role, const char *const reason)
 {
-    char *id = connection_create_stanza_id("role_set");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
     xmpp_stanza_set_to(iq, room);
@@ -849,7 +850,7 @@ xmpp_stanza_t*
 stanza_create_room_kick_iq(xmpp_ctx_t *const ctx, const char *const room, const char *const nick,
     const char *const reason)
 {
-    char *id = connection_create_stanza_id("room_kick");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
     xmpp_stanza_set_to(iq, room);
@@ -886,7 +887,7 @@ stanza_create_room_kick_iq(xmpp_ctx_t *const ctx, const char *const room, const
 xmpp_stanza_t*
 stanza_create_software_version_iq(xmpp_ctx_t *ctx, const char *const fulljid)
 {
-    char *id = connection_create_stanza_id("sv");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_GET, id);
     free(id);
     xmpp_stanza_set_to(iq, fulljid);
@@ -975,7 +976,7 @@ stanza_create_last_activity_iq(xmpp_ctx_t *ctx, const char *const id, const char
 xmpp_stanza_t*
 stanza_create_room_config_submit_iq(xmpp_ctx_t *ctx, const char *const room, DataForm *form)
 {
-    char *id = connection_create_stanza_id("roomconf_submit");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
     xmpp_stanza_set_to(iq, room);
@@ -1052,7 +1053,7 @@ stanza_contains_chat_state(xmpp_stanza_t *stanza)
 xmpp_stanza_t*
 stanza_create_ping_iq(xmpp_ctx_t *ctx, const char *const target)
 {
-    char *id = connection_create_stanza_id("ping");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_GET, id);
     free(id);
     if (target) {
@@ -1171,44 +1172,135 @@ stanza_create_caps_sha1_from_query(xmpp_stanza_t *const query)
     return result;
 }
 
-GDateTime*
-stanza_get_delay(xmpp_stanza_t *const stanza)
+xmpp_stanza_t*
+stanza_get_child_by_name_and_from(xmpp_stanza_t * const stanza, const char * const name, const char * const from)
 {
-    GTimeVal utc_stamp;
-    // first check for XEP-0203 delayed delivery
-    xmpp_stanza_t *delay = xmpp_stanza_get_child_by_name(stanza, STANZA_NAME_DELAY);
-    if (delay) {
-        const char *xmlns = xmpp_stanza_get_attribute(delay, STANZA_ATTR_XMLNS);
-        if (xmlns && (strcmp(xmlns, "urn:xmpp:delay") == 0)) {
-            const char *stamp = xmpp_stanza_get_attribute(delay, STANZA_ATTR_STAMP);
-            if (stamp && (g_time_val_from_iso8601(stamp, &utc_stamp))) {
-                GDateTime *utc_datetime = g_date_time_new_from_timeval_utc(&utc_stamp);
-                GDateTime *local_datetime = g_date_time_to_local(utc_datetime);
-                g_date_time_unref(utc_datetime);
-                return local_datetime;
+    xmpp_stanza_t *child;
+    const char *child_from;
+    const char *child_name;
+
+    for (child = xmpp_stanza_get_children(stanza); child; child = xmpp_stanza_get_next(child)) {
+        child_name = xmpp_stanza_get_name(child);
+        if (child_name && strcmp(name, child_name) == 0) {
+            child_from = xmpp_stanza_get_attribute(child, STANZA_ATTR_FROM);
+            if (child_from && strcmp(from, child_from) == 0) {
+                break;
             }
         }
     }
 
-    // otherwise check for XEP-0091 legacy delayed delivery
-    // stanp format : CCYYMMDDThh:mm:ss
-    xmpp_stanza_t *x = xmpp_stanza_get_child_by_name(stanza, STANZA_NAME_X);
-    if (x) {
-        const char *xmlns = xmpp_stanza_get_attribute(x, STANZA_ATTR_XMLNS);
-        if (xmlns && (strcmp(xmlns, "jabber:x:delay") == 0)) {
-            const char *stamp = xmpp_stanza_get_attribute(x, STANZA_ATTR_STAMP);
-            if (stamp && (g_time_val_from_iso8601(stamp, &utc_stamp))) {
-                GDateTime *utc_datetime = g_date_time_new_from_timeval_utc(&utc_stamp);
-                GDateTime *local_datetime = g_date_time_to_local(utc_datetime);
-                g_date_time_unref(utc_datetime);
-                return local_datetime;
-            }
+    return child;
+}
+
+GDateTime*
+stanza_get_delay(xmpp_stanza_t *const stanza)
+{
+    return stanza_get_delay_from(stanza, NULL);
+}
+
+static GDateTime*
+_stanza_get_delay_timestamp_xep0203(xmpp_stanza_t *const delay_stanza)
+{
+    GTimeVal utc_stamp;
+    const char *xmlns = xmpp_stanza_get_attribute(delay_stanza, STANZA_ATTR_XMLNS);
+
+    if (xmlns && (strcmp(xmlns, "urn:xmpp:delay") == 0)) {
+        const char *stamp = xmpp_stanza_get_attribute(delay_stanza, STANZA_ATTR_STAMP);
+
+        if (stamp && (g_time_val_from_iso8601(stamp, &utc_stamp))) {
+
+            GDateTime *utc_datetime = g_date_time_new_from_timeval_utc(&utc_stamp);
+            GDateTime *local_datetime = g_date_time_to_local(utc_datetime);
+            g_date_time_unref(utc_datetime);
+
+            return local_datetime;
         }
     }
 
     return NULL;
 }
 
+static GDateTime*
+_stanza_get_delay_timestamp_xep0091(xmpp_stanza_t *const x_stanza)
+{
+    GTimeVal utc_stamp;
+    const char *xmlns = xmpp_stanza_get_attribute(x_stanza, STANZA_ATTR_XMLNS);
+
+    if (xmlns && (strcmp(xmlns, "jabber:x:delay") == 0)) {
+        const char *stamp = xmpp_stanza_get_attribute(x_stanza, STANZA_ATTR_STAMP);
+        if (stamp && (g_time_val_from_iso8601(stamp, &utc_stamp))) {
+
+            GDateTime *utc_datetime = g_date_time_new_from_timeval_utc(&utc_stamp);
+            GDateTime *local_datetime = g_date_time_to_local(utc_datetime);
+            g_date_time_unref(utc_datetime);
+
+            return local_datetime;
+        }
+    }
+
+    return NULL;
+}
+
+GDateTime*
+stanza_get_delay_from(xmpp_stanza_t *const stanza, gchar *from)
+{
+    xmpp_stanza_t *delay = NULL;
+
+    // first check for XEP-0203 delayed delivery
+    if (from) {
+        delay = stanza_get_child_by_name_and_from(stanza, STANZA_NAME_DELAY, from);
+    } else {
+        delay = xmpp_stanza_get_child_by_name(stanza, STANZA_NAME_DELAY);
+    }
+
+    if (delay) {
+        return _stanza_get_delay_timestamp_xep0203(delay);
+    }
+
+    // otherwise check for XEP-0091 legacy delayed delivery
+    // stamp format : CCYYMMDDThh:mm:ss
+    if (from) {
+        delay = stanza_get_child_by_name_and_from(stanza, STANZA_NAME_X, from);
+    } else {
+        delay = xmpp_stanza_get_child_by_name(stanza, STANZA_NAME_X);
+    }
+
+    if (delay) {
+        return _stanza_get_delay_timestamp_xep0091(delay);
+    }
+
+    return NULL;
+}
+
+GDateTime*
+stanza_get_oldest_delay(xmpp_stanza_t *const stanza)
+{
+    xmpp_stanza_t *child;
+    const char *child_name;
+    GDateTime* oldest = NULL;
+
+    for (child = xmpp_stanza_get_children(stanza); child; child = xmpp_stanza_get_next(child)) {
+
+        child_name = xmpp_stanza_get_name(child);
+
+        if (child_name && strcmp(child_name, STANZA_NAME_DELAY) == 0) {
+            GDateTime *tmp = _stanza_get_delay_timestamp_xep0203(child);
+
+            if (!oldest || g_date_time_compare(oldest, tmp) == 1)
+                oldest = tmp;
+        }
+
+        if (child_name && strcmp(child_name, STANZA_NAME_X) == 0) {
+            GDateTime *tmp = _stanza_get_delay_timestamp_xep0091(child);
+
+            if (!oldest || g_date_time_compare(oldest, tmp) == 1)
+                oldest = tmp;
+        }
+    }
+
+    return oldest;
+}
+
 char*
 stanza_get_status(xmpp_stanza_t *stanza, char *def)
 {
@@ -2107,7 +2199,7 @@ xmpp_stanza_t*
 stanza_create_command_exec_iq(xmpp_ctx_t *ctx, const char *const target,
     const char *const node)
 {
-    char *id = connection_create_stanza_id("cmdexec");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
     xmpp_stanza_set_to(iq, target);
@@ -2129,7 +2221,7 @@ xmpp_stanza_t*
 stanza_create_command_config_submit_iq(xmpp_ctx_t *ctx, const char *const room,
     const char *const node, const char *const sessionid, DataForm *form)
 {
-    char *id = connection_create_stanza_id("commandconf_submit");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
     xmpp_stanza_set_to(iq, room);
@@ -2179,7 +2271,7 @@ stanza_create_omemo_devicelist_request(xmpp_ctx_t *ctx, const char *const id,
 xmpp_stanza_t*
 stanza_create_omemo_devicelist_subscribe(xmpp_ctx_t *ctx, const char *const jid)
 {
-    char *id = connection_create_stanza_id("omemo_devicelist_subscribe");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
 
@@ -2204,7 +2296,7 @@ stanza_create_omemo_devicelist_subscribe(xmpp_ctx_t *ctx, const char *const jid)
 xmpp_stanza_t*
 stanza_create_omemo_devicelist_publish(xmpp_ctx_t *ctx, GList *const ids)
 {
-    char *id = connection_create_stanza_id("omemo_devicelist_publish");
+    char *id = connection_create_stanza_id();
     xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
     free(id);
 
@@ -2442,9 +2534,9 @@ stanza_attach_origin_id(xmpp_ctx_t *ctx, xmpp_stanza_t *stanza, const char *cons
 }
 
 static void
-_stanza_add_unique_id(xmpp_stanza_t *stanza, char *prefix)
+_stanza_add_unique_id(xmpp_stanza_t *stanza)
 {
-    char *id = connection_create_stanza_id(prefix);
+    char *id = connection_create_stanza_id();
     xmpp_stanza_set_id(stanza, id);
     free(id);
 }
@@ -2463,3 +2555,54 @@ _stanza_create_sha1_hash(char *str)
 
    return b64;
 }
+
+xmpp_stanza_t*
+stanza_get_child_by_name_and_ns(xmpp_stanza_t * const stanza, const char * const name, const char * const ns)
+{
+    xmpp_stanza_t *child;
+    const char *child_ns;
+    const char *child_name;
+
+    for (child = xmpp_stanza_get_children(stanza); child; child = xmpp_stanza_get_next(child)) {
+        child_name = xmpp_stanza_get_name(child);
+        if (child_name && strcmp(name, child_name) == 0) {
+            child_ns = xmpp_stanza_get_ns(child);
+            if (child_ns && strcmp(ns, child_ns) == 0) {
+                break;
+            }
+        }
+    }
+
+    return child;
+}
+
+xmpp_stanza_t*
+stanza_create_avatar_retrieve_data_request(xmpp_ctx_t *ctx, const char *stanza_id, const char *const item_id, const char *const jid)
+{
+    xmpp_stanza_t *iq = xmpp_iq_new(ctx, STANZA_TYPE_GET, stanza_id);
+    xmpp_stanza_set_to(iq, jid);
+
+    xmpp_stanza_t *pubsub = xmpp_stanza_new(ctx);
+    xmpp_stanza_set_name(pubsub, STANZA_NAME_PUBSUB);
+    xmpp_stanza_set_ns(pubsub, STANZA_NS_PUBSUB);
+
+    xmpp_stanza_t *items = xmpp_stanza_new(ctx);
+    xmpp_stanza_set_name(items, "items");
+    char *node = g_strdup_printf("%s", STANZA_NS_USER_AVATAR_DATA);
+    xmpp_stanza_set_attribute(items, STANZA_ATTR_NODE, node);
+    g_free(node);
+
+    xmpp_stanza_t *item = xmpp_stanza_new(ctx);
+    xmpp_stanza_set_name(item, STANZA_NAME_ITEM);
+    xmpp_stanza_set_attribute(item, "id", item_id);
+
+    xmpp_stanza_add_child(items, item);
+    xmpp_stanza_add_child(pubsub, items);
+    xmpp_stanza_add_child(iq, pubsub);
+
+    xmpp_stanza_release(item);
+    xmpp_stanza_release(items);
+    xmpp_stanza_release(pubsub);
+
+    return iq;
+}
