@@ -8,3 +8,9 @@ void add_two_and_complete_returns_second(void **state);
 void add_two_adds_two(void **state);
 void add_two_same_adds_one(void **state);
 void add_two_same_updates(void **state);
+void complete_accented_with_accented(void **state);
+void complete_accented_with_base(void **state);
+void complete_both_with_accented(void **state);
+void complete_both_with_base(void **state);
+void complete_ignores_case(void **state);
+void complete_previous(void **state);
