@@ -8,7 +8,7 @@ void cmd_pgp_start_shows_message_when_connecting(void **state);
 void cmd_pgp_start_shows_message_when_undefined(void **state);
 void cmd_pgp_start_shows_message_when_no_arg_in_console(void **state);
 void cmd_pgp_start_shows_message_when_no_arg_in_muc(void **state);
-void cmd_pgp_start_shows_message_when_no_arg_in_mucconf(void **state);
+void cmd_pgp_start_shows_message_when_no_arg_in_conf(void **state);
 void cmd_pgp_start_shows_message_when_no_arg_in_private(void **state);
 void cmd_pgp_start_shows_message_when_no_arg_in_xmlconsole(void **state);
 #else
