@@ -3,4 +3,5 @@ void cmd_rooms_shows_message_when_disconnecting(void **state);
 void cmd_rooms_shows_message_when_connecting(void **state);
 void cmd_rooms_shows_message_when_undefined(void **state);
 void cmd_rooms_uses_account_default_when_no_arg(void **state);
-void cmd_rooms_arg_used_when_passed(void **state);
+void cmd_rooms_service_arg_used_when_passed(void **state);
+void cmd_rooms_filter_arg_used_when_passed(void **state);
