@@ -14,6 +14,8 @@ void empty_list_when_none_added(void **state)
     roster_create();
     GSList *list = roster_get_contacts(ROSTER_ORD_NAME);
     assert_null(list);
+
+    g_slist_free(list);
     roster_destroy();
 }
 
@@ -23,6 +25,8 @@ void contains_one_element(void **state)
     roster_add("James", NULL, NULL, NULL, FALSE);
     GSList *list = roster_get_contacts(ROSTER_ORD_NAME);
     assert_int_equal(1, g_slist_length(list));
+
+    g_slist_free(list);
     roster_destroy();
 }
 
@@ -34,6 +38,8 @@ void first_element_correct(void **state)
     PContact james = list->data;
 
     assert_string_equal("James", p_contact_barejid(james));
+
+    g_slist_free(list);
     roster_destroy();
 }
 
@@ -45,6 +51,8 @@ void contains_two_elements(void **state)
     GSList *list = roster_get_contacts(ROSTER_ORD_NAME);
 
     assert_int_equal(2, g_slist_length(list));
+
+    g_slist_free(list);
     roster_destroy();
 }
 
@@ -60,6 +68,8 @@ void first_and_second_elements_correct(void **state)
 
     assert_string_equal("Dave", p_contact_barejid(first));
     assert_string_equal("James", p_contact_barejid(second));
+
+    g_slist_free(list);
     roster_destroy();
 }
 
@@ -72,6 +82,8 @@ void contains_three_elements(void **state)
     GSList *list = roster_get_contacts(ROSTER_ORD_NAME);
 
     assert_int_equal(3, g_slist_length(list));
+
+    g_slist_free(list);
     roster_destroy();
 }
 
@@ -89,6 +101,8 @@ void first_three_elements_correct(void **state)
     assert_string_equal("James", p_contact_barejid(james));
     assert_string_equal("Dave", p_contact_barejid(dave));
     assert_string_equal("Bob", p_contact_barejid(bob));
+
+    g_slist_free(list);
     roster_destroy();
 }
 
@@ -108,6 +122,8 @@ void add_twice_at_beginning_adds_once(void **state)
     assert_string_equal("Bob", p_contact_barejid(first));
     assert_string_equal("Dave", p_contact_barejid(second));
     assert_string_equal("James", p_contact_barejid(third));
+
+    g_slist_free(list);
     roster_destroy();
 }
 
@@ -127,6 +143,8 @@ void add_twice_in_middle_adds_once(void **state)
     assert_string_equal("Bob", p_contact_barejid(first));
     assert_string_equal("Dave", p_contact_barejid(second));
     assert_string_equal("James", p_contact_barejid(third));
+
+    g_slist_free(list);
     roster_destroy();
 }
 
@@ -146,6 +164,8 @@ void add_twice_at_end_adds_once(void **state)
     assert_string_equal("Bob", p_contact_barejid(first));
     assert_string_equal("Dave", p_contact_barejid(second));
     assert_string_equal("James", p_contact_barejid(third));
+
+    g_slist_free(list);
     roster_destroy();
 }
 
@@ -158,7 +178,7 @@ void find_first_exists(void **state)
 
     char *search = strdup("B");
 
-    char *result = roster_contact_autocomplete(search, FALSE);
+    char *result = roster_contact_autocomplete(search, FALSE, NULL);
     assert_string_equal("Bob", result);
     free(result);
     free(search);
@@ -172,7 +192,7 @@ void find_second_exists(void **state)
     roster_add("Dave", NULL, NULL, NULL, FALSE);
     roster_add("Bob", NULL, NULL, NULL, FALSE);
 
-    char *result = roster_contact_autocomplete("Dav", FALSE);
+    char *result = roster_contact_autocomplete("Dav", FALSE, NULL);
     assert_string_equal("Dave", result);
     free(result);
     roster_destroy();
@@ -185,7 +205,7 @@ void find_third_exists(void **state)
     roster_add("Dave", NULL, NULL, NULL, FALSE);
     roster_add("Bob", NULL, NULL, NULL, FALSE);
 
-    char *result = roster_contact_autocomplete("Ja", FALSE);
+    char *result = roster_contact_autocomplete("Ja", FALSE, NULL);
     assert_string_equal("James", result);
     free(result);
     roster_destroy();
@@ -198,7 +218,7 @@ void find_returns_null(void **state)
     roster_add("Dave", NULL, NULL, NULL, FALSE);
     roster_add("Bob", NULL, NULL, NULL, FALSE);
 
-    char *result = roster_contact_autocomplete("Mike", FALSE);
+    char *result = roster_contact_autocomplete("Mike", FALSE, NULL);
     assert_null(result);
     roster_destroy();
 }
@@ -206,7 +226,7 @@ void find_returns_null(void **state)
 void find_on_empty_returns_null(void **state)
 {
     roster_create();
-    char *result = roster_contact_autocomplete("James", FALSE);
+    char *result = roster_contact_autocomplete("James", FALSE, NULL);
     assert_null(result);
     roster_destroy();
 }
@@ -218,8 +238,8 @@ void find_twice_returns_second_when_two_match(void **state)
     roster_add("Jamie", NULL, NULL, NULL, FALSE);
     roster_add("Bob", NULL, NULL, NULL, FALSE);
 
-    char *result1 = roster_contact_autocomplete("Jam", FALSE);
-    char *result2 = roster_contact_autocomplete(result1, FALSE);
+    char *result1 = roster_contact_autocomplete("Jam", FALSE, NULL);
+    char *result2 = roster_contact_autocomplete(result1, FALSE, NULL);
     assert_string_equal("Jamie", result2);
     free(result1);
     free(result2);
@@ -240,11 +260,11 @@ void find_five_times_finds_fifth(void **state)
     roster_add("Jamy", NULL, NULL, NULL, FALSE);
     roster_add("Jamz", NULL, NULL, NULL, FALSE);
 
-    char *result1 = roster_contact_autocomplete("Jam", FALSE);
-    char *result2 = roster_contact_autocomplete(result1, FALSE);
-    char *result3 = roster_contact_autocomplete(result2, FALSE);
-    char *result4 = roster_contact_autocomplete(result3, FALSE);
-    char *result5 = roster_contact_autocomplete(result4, FALSE);
+    char *result1 = roster_contact_autocomplete("Jam", FALSE, NULL);
+    char *result2 = roster_contact_autocomplete(result1, FALSE, NULL);
+    char *result3 = roster_contact_autocomplete(result2, FALSE, NULL);
+    char *result4 = roster_contact_autocomplete(result3, FALSE, NULL);
+    char *result5 = roster_contact_autocomplete(result4, FALSE, NULL);
     assert_string_equal("Jamo", result5);
     free(result1);
     free(result2);
@@ -261,9 +281,9 @@ void find_twice_returns_first_when_two_match_and_reset(void **state)
     roster_add("Jamie", NULL, NULL, NULL, FALSE);
     roster_add("Bob", NULL, NULL, NULL, FALSE);
 
-    char *result1 = roster_contact_autocomplete("Jam", FALSE);
+    char *result1 = roster_contact_autocomplete("Jam", FALSE, NULL);
     roster_reset_search_attempts();
-    char *result2 = roster_contact_autocomplete(result1, FALSE);
+    char *result2 = roster_contact_autocomplete(result1, FALSE, NULL);
     assert_string_equal("James", result2);
     free(result1);
     free(result2);
