@@ -2,6 +2,7 @@
 #define TOOLS_HTTP_UPLOAD_H
 
 #include <curl/curl.h>
+#include <pthread.h>
 
 // forward -> ui/win_types.h
 typedef struct prof_win_t ProfWin;
@@ -20,10 +21,9 @@ typedef struct http_upload_t {
 
 //GSList *upload_processes;
 
-void* http_file_put(void *userdata) {}
+void* http_file_put(void *userdata) { return NULL; }
 
-char* file_mime_type(const char* const file_name) {}
-off_t file_size(const char* const file_name) {}
-int is_regular_file(const char *filename) {}
+char* file_mime_type(const char* const file_name) { return NULL; }
+off_t file_size(const char* const file_name) { return 0; }
 
 #endif
