@@ -417,6 +417,7 @@ void cons_alert(void) {}
 void cons_theme_setting(void) {}
 void cons_privileges_setting(void) {}
 void cons_beep_setting(void) {}
+void cons_color_setting(void) {}
 void cons_console_setting(void) {}
 void cons_flash_setting(void) {}
 void cons_splash_setting(void) {}
@@ -427,7 +428,7 @@ void cons_roster_setting(void) {}
 void cons_presence_setting(void) {}
 void cons_wrap_setting(void) {}
 void cons_winstidy_setting(void) {}
-void cons_encwarn_setting(void) {}
+void cons_titlebar_setting(void) {}
 void cons_time_setting(void) {}
 void cons_statuses_setting(void) {}
 void cons_wintitle_setting(void) {}
@@ -440,8 +441,7 @@ void cons_history_setting(void) {}
 void cons_carbons_setting(void) {}
 void cons_receipts_setting(void) {}
 void cons_log_setting(void) {}
-void cons_chlog_setting(void) {}
-void cons_grlog_setting(void) {}
+void cons_logging_setting(void) {}
 void cons_autoaway_setting(void) {}
 void cons_reconnect_setting(void) {}
 void cons_autoping_setting(void) {}
@@ -451,6 +451,7 @@ void cons_inpblock_setting(void) {}
 void cons_winpos_setting(void) {}
 void cons_statusbar_setting(void) {}
 void cons_tray_setting(void) {}
+void cons_os_setting(void) {}
 
 void cons_show_contact_online(PContact contact, Resource *resource, GDateTime *last_activity)
 {
