@@ -2,5 +2,4 @@ void expect_cons_show(char *expected);
 void expect_any_cons_show(void);
 void expect_cons_show_error(char *expected);
 void expect_any_cons_show_error(void);
-void expect_ui_current_print_line(char *message);
-void expect_ui_current_print_formatted_line(char show_char, int attrs, char *message);
+void expect_win_println(char *message);
