@@ -244,7 +244,10 @@ int main(int argc, char* argv[]) {
         unit_test_setup_teardown(cmd_connect_fail_message,
             load_preferences,
             close_preferences),
-        unit_test_setup_teardown(cmd_connect_lowercases_argument,
+        unit_test_setup_teardown(cmd_connect_lowercases_argument_with_account,
+            load_preferences,
+            close_preferences),
+        unit_test_setup_teardown(cmd_connect_lowercases_argument_with_no_account,
             load_preferences,
             close_preferences),
         unit_test_setup_teardown(cmd_connect_asks_password_when_not_in_account,
